rem ============================================================================
rem            Transformations bijectives dimages
rem               Trans_Biject_Images.bas
rem ============================================================================
rem Wikipdia :
rem On appelle transformation bijective dimage une transformation dune image
rem finie de n x m pixels sur elle-mme : 
rem Chaque pixel est donc dplac et aucun pixel nest perdu, ce quon appelle 
rem en mathmatiques une permutation de lensemble des pixels et en langage 
rem courant un mlange.
rem De manire triviale, n applications de cette transformation redonnent limage
rem initiale.
rem Cette proprit est gnrale : pour toute transformation bijective dimage,
rem il existe un plus petit entier k telle que applique k fois, la transformation
rem redonne limage initiale.
rem ============================================================================
rem Les transformations bijectives dimages les plus connues sont
rem * La transformation du photomaton
rem * La transformation du boulanger (et sa variante le fer  cheval de Smale)
rem * La transformation de Hilbert
rem ============================================================================
rem Le nombre dtapes avant de voir rapparaitre limage est parfois trs grand
rem et dpend dune part de la transformation et dautre part de la taille de 
rem limage. 
rem Par exemple une image carre dont le ct est une puissance de 2 reviendra
rem trs vite, alors quavec deux nombres quelconques, le retour peut-tre 
rem extrmement long.
rem Durant ces tapes, on passe parfois par des reconstitutions trs proches de
rem limage initiale.
rem ============================================================================
rem *** Transformation du photomaton
rem La transformation du clich Photomaton est une description dun type de 
rem mlange analogue  un clich Photomaton qui  partir dune image en fabrique
rem quatre de plus petites dimensions, et ainsi de suite par itration.
rem Cette transformation est un cas particulier de transformations bijectives 
rem dimages.
rem ============================================================================
rem Principe de la transformation du photomaton
rem Le principe de cette transformation est le suivant : 
rem pour obtenir une nouvelle image, limage originale est decompose en 4 images
rem rtrcies rcursivement. 
rem Limage est tout dabord dcoupe en carrs de 4 pixels (2  2) puis le pixel
rem en haut  droite de chaque carr sert  recomposer une image de taille 1/2 
rem en haut  droite, idem pour la partie en haut  gauche, en bas  droite, 
rem en bas  gauche. 
rem Cette transformation ne fonctionne quavec des images dont la hauteur et la 
rem largeur sont paires.
rem Si on rpte un certain nombre de fois cette transformation, on retrouve 
rem limage de dpart. 
rem Le nombre ditrations sappelle priode de retour. 
rem Il se calcule comme suit pour une image de dimension 2n x 2m pixels :
rem On dtermine le plus petit entier p tel que 2n-1 divise 2^p-1;
rem On dtermine le plus petit entier k tel que 2m-1 divise 2^k-1;
rem On calcule le ppcm de p et k. 
rem Le rsultat obtenu est la priode cherche.
rem ============================================================================
rem Dans le cas o la taille de limage est 2^p x 2^k, la priode est ppcm(p,k).
rem Nous allons travailler avec des images carres de dimensions une puissance
rem de deux, par exemple 256 x 256 ou 512 x 512.
rem De cette faon le calcul de la priode sera simplifi et en plus le retour
rem  limage dorigine sera rapide.
rem ============================================================================
rem Important :
rem Notez bien que les 4 images qui apparaissent aprs une tape de transformation
rem ne sont pas identiques comme elles le seraient avec lappareil photographique
rem de la socit Photomaton. 
rem Les quatre images sont bien diffrentes au sens des pixels quelles contiennent.
rem Elles proviennent dune redistribution des pixels de limage initiale sans 
rem aucune duplication ni perte.
rem ============================================================================
rem *** Transformation du boulanger
rem La transformation du boulanger est une transformation base sur lide dun
rem mlange analogue au ptrissage par un boulanger qui tire une pte jusqu 
rem ce quelle soit dpaisseur moiti, puis la coupe en deux et superpose les 
rem deux moitis pour lui redonner sa dimension initiale, et ainsi de suite.
rem ============================================================================
rem La transformation du boulanger se dfinit sur [0,1] de la faon suivante:
rem      ________________________________________________
rem     |                                                |
rem     |  S(x,y) = (2x  , y/2)        si 0 <= x <= 1/2  |
rem     |  S(x,y) = (2x-1, (y+1)/2)    sinon             |
rem     |________________________________________________|
rem
rem Une version alternative consiste  replier plutt que couper et resuperposer
rem les deux demi-ptons. Cest la transformation dite du fer  cheval de Smale.
rem ============================================================================
rem &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
rem ============================================================================

dim f$,fn$,ext$,n,p,t
dim largeur,hauteur : ' dimensions de l'image
dim exit
label clic
application_title "Transformations bijectives dimages"
dir_change "C:\Users\MICROTEK\Desktop\Tranformations_Images" : ' Adapter le chemin
f$ = dir_current$ +"\lancelot" 
fn$ = f$ : ext$ = ".bmp"
Dimensions(fn$+ext$) : ' rcuperer les dimensions (largeur et hauteur) de l'image 
Menu()
create_hide 
picture 10 : picture 20 : picture 30
alpha 11 : top 11,10 : left 11,largeur/2     : font_color 11,255,255,0
alpha 21 : top 21,10 : left 21,2*largeur     : font_color 21,255,255,0
alpha 31 : top 31,10 : left 31,3*largeur+150 : font_color 31,255,255,0  
end
rem ============================================================================
SUB Menu()
    dim_local i
    main_menu 1
        sub_menu 2 : parent 2,1 : caption 2,"Transformations"
        sub_menu 3 : parent 3,2 : caption 3,"Transformation du photomaton"
        sub_menu 4 : parent 4,2 : caption 4,"Transformation du boulanger"
        sub_menu 5 : parent 5,2 : caption 5,"-"
        sub_menu 6 : parent 6,2 : caption 6,"Quitter"
        sub_menu 7 : parent 7,1 : caption 7,"Aide"
        sub_menu 8 : parent 8,7 : caption 8,"Infos"
        sub_menu 9 : parent 9,7 : caption 9,"A-Propos"
    for i = 3 to 9 : on_click i,clic : next i        
END_SUB
rem ============================================================================
Clic:
    select number_click
        case 3 : GUI_Photomaton()
        case 4 : GUI_Boulanger()
        case 6 : Quitter()
        case 8 : Infos()
        case 9 : Propos()
    end_select
return
rem ============================================================================
SUB GUI_Photomaton()
    width 0,2*largeur+100 : height 0,hauteur +200 : color 0,100,50,20  
    width 10,largeur : height 10,hauteur : top 10,50 : left 10,50
    width 20,largeur : height 20,hauteur : top 20,50 : left 20,50+width(10)+10
    show 10 : show 20
    p = Periode(largeur,hauteur)
    Traitement_Photomaton(p) 
END_SUB
rem ============================================================================
' Traitement
SUB Traitement_Photomaton(p)
    dim_local n,im$
    inactive 2 : inactive 7
    exit = 0
    im$ = f$ + "_Photomathon"
    for n = 1 to p
        caption 0,"Transformation du Photomaton. Traitement en cours ..." + str$(n) + " / " + str$(p) + " ... <ESC> pour arrter"
        2d_target_is 10 : file_load 10,fn$ + ext$
        2d_target_is 20 : cls
        Photomaton()
        if exit = 1 then active 2 : active 7 : exit_sub
        file_save 20,im$ + "_" + str$(n) + ext$
        fn$ = im$ + "_" + str$(n) 
    next n
    caption 0,"Traitement termin. On retrouve bien l'image de dpart"
    active 2 : active 7
END_SUB
rem ============================================================================
SUB Photomaton()
    dim_local x,y,nx,ny,r,g,b
    for x = 0 to largeur-1
        for y = 0 to hauteur-1
            r = color_pixel_red(10,x,y)
            g = color_pixel_green(10,x,y)
            b = color_pixel_blue(10,x,y)
            if (even(x) = 1) and (even(y) = 1) : ' x et y sont pairs
               nx = int(x/2) : ny = int(y/2)
            else
               if even(x) = 1                  : ' x est pair et y impair
                  nx = int(x/2) : ny = int(hauteur/2) + int(y/2)
               else
                  if even(y) = 1               : ' x est impair et y pair
                     nx = int(largeur/2) + int(x/2) : ny = int(y/2)
                  else                         : ' x et y sont impairs
                     nx = int(largeur/2) + int(x/2) : ny = int(hauteur/2) + int(y/2)
                  end_if
               end_if
            end_if
            2d_pen_color r,g,b : 2d_point nx,ny 
            if scancode = 27 then exit = 1 : exit_sub
        next y
        display
    next x

END_SUB
rem ============================================================================
SUB GUI_Boulanger()
    width 0,4*Largeur+200 : height 0,Hauteur + 200 : color 0,100,50,20  
    width 10,Largeur : height 10,Hauteur : top 10,30 : left 10,50
    width 20,2*Largeur : height 20,Hauteur : top 20,30 : left 20,50+width(10)+10
    width 30,largeur : height 30,hauteur : top 30,30 : left 30,3*largeur + 70    
    show_all
    p = 2 * Periode(Largeur,Hauteur) + 1 
    Traitement_Boulanger(p)
END_SUB
rem ============================================================================
SUB Traitement_Boulanger(p)
    2d_target_is 10 : file_load 10,fn$ + ext$ : caption 11,"Etape 0"
    2d_target_is 20   
    All_Boulanger(p)
END_SUB
rem ============================================================================
' Visualiser l'ensemble des transformations du boulanger 
' avant le retour  l'image initiale
SUB All_Boulanger(p)
    dim_local n,im$
    2d_target_is 10 
    inactive 2 : inactive 7
    im$ = f$ + "_Boulanger"
    exit = 0
    for n = 1 to p
        caption 0,"Transformation du boulanger. Traitement en cours ..." + str$(n) + " / " + str$(p) + " ... <ESC> pour arrter"        
        2d_target_is 10 : file_load 10,fn$ + ext$
        2d_target_is 30 : cls
        2d_target_is 20 : cls        
        Boulanger_Etirer(n)  : if exit = 1 then active 2 : active 7 :  exit_sub
        Boulanger_Replier(n) : if exit = 1 then active 2 : active 7 : exit_sub      
        file_save 30,im$ + "_" + str$(n) + ext$        
        fn$ = im$ + "_" + str$(n) 
        caption 11,"Etape " + str$(n)
    next n   
    2d_target_is 10 : file_load 10,f$ + ext$
    2d_target_is 20 : cls
    caption 0,"Traitement termin. On retrouve bien l'image de dpart"
    caption 11,"Image de dpart"
    caption 21,""
    caption 31,"Etape " + str$(p)
    active 2 : active 7
END_SUB
rem ============================================================================
SUB Boulanger_Etirer(n)
    dim_local x,y,x1,y1,r,g,b,nx,ny 
    caption 21,"Etirement " + str$(n)    
    for x = 0 to largeur-1
        for y = 0 to hauteur-1
            r = color_pixel_red(10,x,y)
            g = color_pixel_green(10,x,y)
            b = color_pixel_blue(10,x,y)            
            if even(y) = 1
               nx = 2*x : ny = int(y/2)
            else
               nx = 2*x+1 : ny = int(y/2)
            end_if                                             
            2d_pen_color r,g,b : 2d_point nx,ny 
            if scancode = 27 then exit = 1 : exit_sub
        next y
        display
    next x
END_SUB
rem ============================================================================
SUB Boulanger_Replier(n)
    dim_local x,y,x1,y1,r,g,b,nx,ny,h,l
    caption 31,"Repliement " + str$(n)
    2d_target_is 30 : cls
    h = hauteur/2 
    l = 2*largeur 
    for x = 0 to l-1
        for y = 0 to h-1
            r = color_pixel_red(20,x,y)
            g = color_pixel_green(20,x,y)
            b = color_pixel_blue(20,x,y)            
            if x < int(l/2)       
               nx = x : ny = y
            else
               nx = l-x-1 : ny = 2*h-y-1
            end_if                                                        
            2d_pen_color r,g,b : 2d_point nx,ny 
            if scancode = 27 then exit = 1 : exit_sub
        next y
        display
    next x
    caption 31,""
END_SUB
rem ============================================================================
' Rcuperer les dimensions (largeur et hauteur) de l'image image$
SUB Dimensions(image$)
    filebin_open_read 999,image$
    filebin_position 999,18
    largeur = filebin_read(999) + 256 * filebin_read(999)
    filebin_position 999,22
    hauteur = filebin_read(999) + 256 * filebin_read(999)
    filebin_close 999
END_SUB
rem ============================================================================
' Fonction Plus Grand Commun Diviseur de deux entiers a et b
' Cette fonction sera utilise dans le calcul du nombre d'tapes pour raliser
' la transformation.
FNC PGCD(a,b)
    dim_local r
    a = abs(a) : b = abs(b)
    if a > b then r = b : b = a : a = r
    repeat
        r = mod(a,b) : a = b : b = r
    until r = 0
    result a
END_FNC
rem ============================================================================
' Fonction retournant la priode (nombre de transformations) 
FNC Periode(p1,p2)
    dim_local q1,q2
    q1 = 0
    repeat
        q1 = q1 + 1
    until mod(power(2,q1)-1,p1-1) = 0
    q2 = 0
    repeat
        q2 = q2 + 1
    until mod(power(2,q2)-1,p2-1) = 0
    result int(q1*q2 / pgcd(q1,q2))
END_FNC
rem ============================================================================
SUB Quitter()
    if message_confirmation_yes_no("Vous voulez vraiment quitter ?") = 1
       terminate
    end_if
END_SUB
rem ============================================================================
SUB Infos()
    dim_local t$
    t$ = "Une transformation bijective d'une image dplace les points d'une image d'un endroit  un autre sans en ajouter ni en enlever aucun." + chr$(13)
    t$ = t$ + "Une proprit remarquable de ces transformations bijectives est qu'elles reviennent toujours au point de dpart aprs un nombre d'applications plus ou moins important." + chr$(13) + chr$(13)
    t$ = t$ + "Ce programme traite les deux plus importantes transformations les plus connues  savoir la transformation du photomaton et la tranformation du boulanger."+chr$(13)
    t$ = t$ + "La transformation du photomaton consiste  raliser lopration suivante sur les numros des lignes : " + chr$(13)
    t$ = t$ + "On prend les lignes de rang pair quon fait suivre de celles de numro impair." + chr$(13)
    t$ = t$ + "De mme, pour les numros des colonnes  cela explique lapparition de quatre versions en plus petit de limage initiale." + chr$(13) + chr$(13)
    t$ = t$ + "La transformation du boulanger sappelle ainsi car elle sapparente au travail du boulanger qui ralise une pte feuillete."+chr$(13)
    t$ = t$ + "Limage est tout dabord tire puis coupe en deux dans le sens vertical pour placer la partie de droite sous la partie gauche en la faisant tourner de 180"+chr$(13)
    t$ = t$ + "La transformation du boulanger est donc la succession dun tirement et dun repliement." + chr$(13)
    t$ = t$ + "Partant dun tableau n x n on obtinet encore un tableau n x n."+chr$(13)
    t$ = t$ + "On part dun tableau n  n, avec n pair dont chaque lment reprsente un pixel."+chr$(13)
    t$ = t$ + "On va appliquer deux transformations lmentaires  chaque fois :"+chr$(13)
    t$ = t$ + " 1 / tirer." +chr$(13) 
    t$ = t$ + "Le principe est le suivant :"+chr$(13) 
    t$ = t$ + "les deux premires lignes (chacune de longueur n) produisent une seule ligne de longueur 2n en mixant les valeurs de chaque ligne en alternant un lment du haut, un lment du bas."+chr$(13)
    t$ = t$ + " 2 / Replier."+chr$(13) 
    t$ = t$ + "Le principe est le suivant : "+chr$(13)
    t$ = t$ + "la partie droite dun tableau tir est retourne (en la faisant tourner de 180), puis ajoute sous la partie gauche."+chr$(13) 
    t$ = t$ + "Pour que cette tranformation soit bien dfinie, il est ncessaire que les dimensions de limage soient paires."+chr$(13)
    t$ = t$ + "Partant dun tableau n/2  2n on obtient un tableau n  n."
    message t$
END_SUB
rem ============================================================================
SUB Propos()
    dim_local t$
    t$ = "Transformations bijectives d'images : transformations du photomaton et du boulanger" + chr$(13)
    t$ = t$ + "Auteur : Papydall" + chr$(13)
    t$ = t$ + "Date   : 30 / 09 / 2022" + chr$(13)
    t$ = t$ + "Dernire modif : 01 / 10 / 2022" 
    message t$
END_SUB
rem ============================================================================
rem &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
rem ============================================================================



