
rem ============================================================================
rem                    Calcul du primtre de lellipse
rem ============================================================================
' Paramtres de l'ellipse :
' dim a,b : ' respectivement demi-grand axe et demi-petit axe de l'ellipse
' dim f   : ' focale       =   sqr(a*a - b*b)
' dim h   : ' rapport      =   ((a-b)*(a-b)) / ((a+b)*(a+b))
' dim e   : ' excentricit =   sqr((1-(b*b)/(a*a)))
' dim s   : ' aire         =   pi*a*b
' dim p   : ' primtre    =   ??????
rem ============================================================================
rem Le calcul du primtre de lellipse nest pas une chose facile.
rem La formule de la valeur exacte est une intgrale elliptique du second ordre.
rem Elle est transcendante et na pas de solution analytique.
rem On la calcule par intgration numrique ou par approximations rationnelles.
rem
rem Pour une ellipse donne par son quation paramtrique :
rem                      __________________
rem                     |                  |
rem                     |  x = a * cos(t)  |
rem                     |  y = b * sin(t)  |
rem                     |  0 <= t <= 2*pi  |
rem                     |__________________|
rem                                
rem La formule exacte qui donne le primtre est : (elle nest pas facile  calculer)
rem   ________________________________________________________________________
rem  |                                                                        |
rem  |  p = 4*a*intgrale de 0  pi/2 de la racine carre de (1-e*sint) dt  |  
rem  |________________________________________________________________________|
rem
rem ============================================================================
rem Heureusement, il existe plusieurs approximations de la circonfrence de
rem lellipse dont celle de Ramanujan qui donne une trs bonne appoximation.
rem
rem    __________________________________________________
rem   |                                                  |
rem   |   Formule de Ramanujan :                         |
rem   |                                                  |
rem   |   p = pi * (3*(a+b) - sqr((3*a+b) * (a+3*b)))    |
rem   |__________________________________________________|

rem ============================================================================
dim t$
dim a,b
' Application :
' Calcul de la longueur du mridien terrestre par les diffrentes formules avec
 a = 6378137         : ' Rayon  l'quateur terrestre.
 b = 6356752.3141    : ' Rayon au ple.
 
application_title "Calcul du primtre de lellipse"
rem ============================================================================
t$ = "Approximation de Ramanujan :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Ramanujan(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

t$ = "Approximation de Kepler :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Kepler(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

t$ = "Approximation de Sipos :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Sipos(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

t$ = "Approximation nave :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Naive(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

t$ = "Approximation de Peano :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Peano(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

t$ = "Approximation d'Euler :" + chr$(13)
t$ = t$ + "Longueur calcule du mridien terrestre : "
t$ = t$ + str$(Circonference_Ellipse_Euler(a,b)) + " m" + chr$(13)
t$ = t$ + "Longueur relle du mridien terrestre      : 40007862.9164813 m"
Message t$

terminate
rem ============================================================================
' Trs bonne approximation
FNC Circonference_Ellipse_Ramanujan(a,b)
    result pi * (3*(a+b) - sqr((3*a+b) * (a+3*b)))
END_FNC
rem ============================================================================
' C'st la 1re approximation utilise par Johannes Kepler
FNC Circonference_Ellipse_Kepler(a,b)
    result 2*pi*sqr(a*b)
END_FNC
rem ============================================================================
' Meilleure approximation que celle de Kepler
FNC Circonference_Ellipse_Sipos(a,b)
    dim_local n,d
    n = (a+b) : n = n*n
    d = sqr(a)+sqr(b) : d = d*d
    result 2*pi*(n/d)
END_FNC
rem ============================================================================
' Approximation nave mais meilleure que celle de Kepler
FNC Circonference_Ellipse_Naive(a,b)
    result pi*(a+b)
END_FNC
rem ============================================================================
' Trs bonne approximation
FNC Circonference_Ellipse_Peano(a,b)
    result pi*(3*(a+b)/2 - sqr(a*b))
END_FNC
rem ============================================================================
FNC Circonference_Ellipse_Euler(a,b)
    result pi * sqr(2*(a*a+b*b))
END_FNC
rem ============================================================================