rem ============================================================================
rem                    Calculs_Astronomiques.bas Par Papydall
rem                         Version 2 du 04 / 01 / 2023
rem ============================================================================
rem         Les formules utilises dans ce programme sont issues du livre
rem              "Astronomical Algorithms Second Edition" de Jean Meeus
rem ============================================================================
' dclaration des variables globales
dim heure,minute,seconde,jour,mois,annee 
Dim b, Y, m, a, jj, t, t2, Ct1, Ct, T2000, T2_2000, T3_2000, T4_2000, l, c, v
dim Omega, longitude, d, e, h, longitude_soleil, excentricite, mercure
Dim venus, longitude_moyenne_terre, anomalie_soleil
Dim mars, jupiter, saturne, uranus, neptune
Dim a1, a2, a3, Om, Longitude_noeud, W1, l_prime, Anomalie_lune, f, n
dim petit_l, dzeta_lune, nu, nutation_en_longitude
Dim nutation_en_obliquite, Obliquite, Correction, longitude_lune, l1, d1, d2
dim latitude, latitude_lune, b1, p, distance_terre, p1, ascension, Bidouille
dim declinaison, fraction_illuminee, Signe$, elongation_lune$
rem ============================================================================

Application_title "Calculs astronomiques par PAPYDALL"

Exemples_d_appel_des_differentes_fonctions_du_programme()
Position_Lune()
end
rem ============================================================================
' Exemples d'appel  des diffrentes fonctions du programmes
SUB Exemples_d_appel_des_differentes_fonctions_du_programme()
    Get_Date_heure()

    print HMS_To_Degrees(9,14,55.8)
    print DMS_To_Hours("-",0,32,41)
    print atn2(1,1)
    print Bissextile(2020)
    print Bissextile(2023)
    print Jour_Julien(jour,mois,annee)
    print Date_From_Jour_Julien$(2433503.5) : ' ma date de naissance
    print Nombre_de_Jours_entre_2_dates("10/08/1950","04/01/2023")
    print Day_Of_Week$(jour,mois,annee)
    print Day_Of_Year(jour,mois,annee)
    print Date_From_Day_Of_Year$(123,2023)
    print Date_Of_Easter$(annee)
    print
    print Distance_Sur_Terre$(2,20,55,"E",48,51,12,"N",77,03,11,"W",38,55,17,"N") :' distance entre Paris et Washington
    print Distance_Sur_Terre$(2,20,55,"E",48,51,12,"N",05,22,51,"E",43,17,49,"N") :' distance entre Paris et Marseille
    print Distance_Sur_Terre$(2,20,55,"E",48,51,12,"N",10,09,56,"E",36,49,08,"N") :' distance entre Paris et Tunis
END_SUB
rem ============================================================================
' Lire la date et l'heure systme
SUB Get_Date_heure()
    heure   = time_hour 
    minute  = time_minute  
    seconde = time_second 
    jour    = date_day 
    mois    = date_month 
    annee   = date_year 
END_SUB
rem ============================================================================
' Convertir un temps (donn en heures, minutes et secondes) en degrs.
' L'ascension droite est gnralement donne en heure, minutes et secondes.
' Il est ncessaire de convertir cette valeur en degrs (puis en radians si
' besoin est) pour pouvoir effectuer les calcules trigonomtriques.
' REMARQUE : une heure correspond  15 degrs.
FNC HMS_To_Degrees(h,m,s)
    result (h + m/60 + s/3600) * 15  
END_FNC
rem ============================================================================
' Convertir un temps (donn en degrs, minutes et secondes) en heures.
' On tient compte des valeurs ngatives de l'angle horaire
FNC DMS_To_Hours(signe$,degre,minutee,seconde)
    dim_local d,m,s,heuree
    if signe$ = "-"
       d = 0-abs(degre) : m = 0-abs(minutee) : s = 0 - abs(seconde)
    else
       d = degre : m = minutee : s = seconde
    end_if
    result (d + m / 60 + s / 3600)
    
END_FNC
rem ============================================================================
' ATN2 : calcul l'ArcTangente(y/x) en tenant compte des signes de X et de Y.
' Le rsultat (en radians) appartient  l'un des 4 quadrants.
FNC ATN2(x,y)    
    If x = 0
       result = Sgn(y) * pi/2
    Else
       If x > 0
          result  Atn(y / x)
       Else
          if x < 0 and y = 0
             result atn(y / x) - sgn(x) * pi
          else
             result Atn(y / x) + Sgn(y) * pi
          end_if
       End_if
    end_if
END_FNC
rem ============================================================================
' Dterminer si l'anne est bissextile
' Retourne 1 si l'anne est bissextile, 0 si non
FNC Bissextile(annee)
    if (mod(annee,400) = 0) or (mod(annee,4) = 0) and (mod(annee,100) <> 0)
        result 1 : ' bissextile
    else
        result 0 : ' non bissextile"
    end_if
END_FNC
rem ============================================================================
' Dterminer le Jour Julien  partir d'une date
FNC Jour_Julien(jour,mois,annee)
    dim_local a,b,d,m,y,JD
    d = jour : m = mois : y = annee
    if m < 3 then y = y - 1 : m = m + 12
    a = int(y/100) : b = 2 - a + int(a/4)
    JD = int(365.25*(y+4716)) + int(30.6001*(m+1)) + d + b - 1524.5
    result JD
END_FNC
rem ============================================================================
' Dterminer la date  partir du Jour Julien
FNC Date_From_Jour_Julien$(Jour_Julien)
    dim_local JD,Z,A,B,C,D,E,F,Alfa,day,year,m
    JD = Jour_Julien + 0.5 : Z = int(JD) : F = frac(JD)
    if Z < 2299161
       A = Z
    else
       alfa = int((z-1867216.25)/36524.25)
       a = z + 1 + alfa - int(alfa/4)
    end_if
    b = a + 1524
    c = int((b-122.1)/365.25)
    d = int(365.25*c)
    e = int((b-d)/30.6001)
    day = b-d-int(30.6001*e) + f
    if e < 14 then m = e-1 : else : m = e-13
    if m > 2 then year = c-4716 : else : year = c-4715
    result str$(day) + "/" + str$(m) +"/"+str$(year)
END_FNC
rem ============================================================================
' Dterminer le nombre de jours entre 2 dates
' d1$ et d2$ sous forme jj/mm/aaaa
FNC Nombre_de_Jours_entre_2_dates(d1$,d2$)
    dim_local j1,j2,m1,m2,a1,a2,jd1,jd2
    j1 = mid$(d1$,1,2) : m1 = mid$(d1$,4,2) : a1 = mid$(d1$,7,4)
    j2 = mid$(d2$,1,2) : m2 = mid$(d2$,4,2) : a2 = mid$(d2$,7,4)
    jd1 = Jour_Julien(j1,m1,a1) 
    jd2 = Jour_Julien(j2,m2,a2) 
    result (jd2-jd1) 
END_FNC
rem ============================================================================
' Dterminer le nom du jour de la semaine 
FNC Day_Of_Week$(jour,mois,annee)
    dim_local j,m,a,jd,r,jour$
    j = jour : m = mois : a = annee
    jd = Jour_Julien(j,m,a) + 1.5
    r = mod(jd,7)
    select r
        case 0 : jour$ = "DIMANCHE" 
        case 1 : jour$ = "LUNDI"   
        case 2 : jour$ = "MARDI"    
        case 3 : jour$ = "MERCREDI" 
        case 4 : jour$ = "JEUDI"    
        case 5 : jour$ = "VENDREDI" 
        case 6 : jour$ = "SAMEDI"   
    end_select
    result jour$ 
END_FNC
rem ============================================================================
' Dterminer le numro N du jour dans l'anne
FNC Day_Of_Year(j,m,a)
    dim_local k
    if Bissextile(a) > 0 then k = 1 : else : k = 2
    result int((275*m)/9) - k * int((m+9)/12) + j - 30    
END_FNC
rem ============================================================================
' Problme inverse de Day_Of_Year
' On connait le numro N du jour dans l'anne, on cherche la date correspondante
' c..d le jour et le mois
' --------------------------
' Algorithme de A.pouplier de la Socit Astronomique de Lige, Belgique
FNC Date_From_Day_Of_Year$(n,a)
    dim_local k,m,d
    Bissextile(a)
    if Bissextile(a) > 0 then k = 1 : else : k = 2
    m = int((9*(k+n)/275)+0.98)
    if n < 32 then m = 1
    d = n - int((275*m)/9) + k * int((m+9)/12) + 30
    result str$(d) + "/" + str$(m) + "/" + str$(a)
END_FNC
rem ============================================================================
' Dterminer le jour de Pques
FNC Date_Of_Easter$(annee)
    dim_local x,a,b,c,d,e,f,g,h,i,k,l,m,n,p
    x = annee
    a = mod(x,19) : b = int(x/100) : c = mod(x,100)
    d = int(b/4) : e = mod(b,4) : f = int((b+8)/25)
    g = int((b-f+1)/3) : h = mod((19*a+b-d-g+15),30) : i = int(c/4)
    k = mod(c,4) : l = mod((32+2*e+2*i-h-k),7) : m = int((a+11*h+22*l)/451)
    n = int((h+l-7*m+114)/31) : p = mod((h+l-7*m+114),31)
    result str$(p+1) + "/" + str$(n)
END_FNC
rem ============================================================================
' Calculer la distance entre 2 points situs sur la surface du globe
' connaissant leur longitude et leur latitude
' La longitude comporte 4 paramtres : degrs, minutes, secondes et direction(E/W)
' La lattitude comporte 4 paramtres : degrs, minutes, secondes et direction(N/S)
' Pour 2 points sur le globe, la procdure ncessite en tout 16 paramtres !
FNC Distance_Sur_Terre$(d1,m1,s1,sens1$,d2,m2,s2,sens2$,d3,m3,s3,sens3$,d4,m4,s4,sens4$)
    dim_local a,d,sens$,r,r1,r2,r3,r4,phi1,phi2,f,g,lambda,s,c,omega,h1,h2,l1,l2
    if upper$(sens1$) = "E" then sens$ = "-" : else : sens$ = "+"
    r1 = DMS_To_Hours(sens$,d1,m1,s1) 
    if upper$(sens2$) = "N" then sens$ = "+" : else : sens$ = "-"
    r2 = DMS_To_Hours(sens,d2,m2,s2) 
    
    if upper$(sens3$) = "E" then sens$ = "-" : else : sens$ = "+"
    r3 = DMS_To_Hours(sens$,d3,m3,s3) 
    if upper$(sens4$) = "N" then sens$ = "+" : else : sens$ = "-"
    r4 = DMS_To_Hours(sens$,d4,m4,s4) 

    a = 6378.137 : ' Rayon quatorial de la Terre
    l1 = r1 : l2 = r3 : phi1 = r2 : phi2 = r4
    f = (phi1 + phi2) / 2    : f = Degree_to_Radian(f) 
    g = (phi1 - phi2) / 2    : g = Degree_To_Radian(g) 
    lambda =  (l1 - l2) / 2  : lambda = Degree_To_Radian(lambda)
    s = sin(g)*sin(g)*cos(lambda)*cos(lambda) + cos(f)*cos(f)*sin(lambda)*sin(lambda)
    c = cos(g)*cos(g)*cos(lambda)*cos(lambda) + sin(f)*sin(f)*sin(lambda)*sin(lambda)
    omega = atn(sqr(s/c)) : r = sqr(s*c) / omega : d = 2 * omega * a
    h1 = (3*r-1)/(2*c) : h2 = (3*r+1)/(2*s)
    result str$(d) +" km"
END_FNC
rem ============================================================================
' Calculer la position gocentrique de la Lune
Sub Position_Lune()
    dim_local tex$
    Get_Date_heure()
    tex$ = string$(10,"*") + "  POSITION DE LA LUNE  " + string$(10,"*") + chr$(13) + chr$(13)
' ------------------------------------------------------------------------------
    tex$ = tex$ + "Instant G.M.T.  =  " + str$(Jour) + " / " + str$(Mois) + " / " + str$(Annee) + "  " + str$(heure) + ":" + str$(minute) + ":" + str$(Seconde)
' ------------------------------------------------------------------------------
    If Mois > 2 Then Y = Annee: m = Mois :Else: Y = Annee - 1: m = Mois + 12
    b = 0
    If ((Y * 10000 + m * 100 + Jour) > 15821015) Then a = Int(Y / 100): b = 2 - a + Int(a / 4)
    jj = 1720994.5 + Int(365.25 * Y) + Int(30.6001 * (m + 1)) + b + Jour + heure / 24 + minute / 1440 + Seconde / 86400
    t = (jj - 2415020) / 36525 : t2 = t * t : Ct1 = 180 / PI : Y = 2 * PI
    Ct = 0.00000484814 : T2000 = (jj - 2451545) / 36525
    T2_2000 = T2000 * T2000 : T3_2000 = T2_2000 * T2000 : T4_2000 = T2_2000 * T2_2000
    l = (279.69668 + 36000.76892 * t) + 0.0003025 * t * t : l = l / Ct1
    m = (358.47583 + 35999.04975 * t) - 0.00015 * t * t - 0.0000033 * t * t * t
    m = m / Ct1 : anomalie_soleil = m
    c = (1.91946 / Ct1 - 0.004789 / Ct1 * t - 0.000014 / Ct1 * t * t) * Sin(m) + (0.020094 / Ct1 - 0.0001 / Ct1 * t) * Sin(2 * m) + 0.000293 / Ct1 * Sin(3 * m)
    l = l + c : v = m + c : Omega = 259.18 / Ct1 - 1934.142 / Ct1 * t
    longitude = l - 0.00569 / Ct1 - 0.00479 / Ct1 * Sin(Omega)
    a = 153.23 / Ct1 + 22518.7541 / Ct1 * t
    b = 216.57 / Ct1 + 45037.5082 / Ct1 * t
    c = 312.69 / Ct1 + 32964.3577 / Ct1 * t
    d = 350.74 / Ct1 + 445267.1142 / Ct1 * t - 0.00144 / Ct1 * t * t
    e = 231.19 / Ct1 + 20.2 / Ct1 * t
    h = 353.4  / Ct1 + 65928.7155 / Ct1 * t
    longitude_soleil = longitude + 0.00134 / Ct1 * Cos(a) + 0.00154 / Ct1 * Cos(b) + 0.002 / Ct1 * Cos(c) + 0.00179 / Ct1 * Sin(d) + 0.00178 / Ct1 * Sin(e)
    longitude_soleil = longitude_soleil - Y * Int(longitude_soleil / Y)
    e = 1 - 0.002516 * T2000 - 0.0000074 * T2_2000 : excentricite = e * 0.01675104
    mercure = (252.250906 + 149472.674636 * T2000) / Ct1 : mercure = mercure - Y * Int(mercure / Y)
    venus = (181.979801 + 58517.815676 * T2000) / Ct1 : venus = venus - Y * Int(venus / Y)
    longitude_moyenne_terre = (100.46645 + 35999.372854 * T2000) / Ct1
    longitude_moyenne_terre = longitude_moyenne_terre - Y * Int(longitude_moyenne_terre / Y)
    mars = (355.433275 + 19140.299331 * T2000) / Ct1 : mars = mars - Y * Int(mars / Y)
    jupiter = (34.351484 + 3034.905675 * T2000) / Ct1 : jupiter = jupiter - Y * Int(jupiter / Y)
    saturne = (50.077471 + 1222.113794 * T2000) / Ct1 : saturne = saturne - Y * Int(saturne / Y)
    uranus = ((314 + 3 / 60 + 18.01841 / 3600) + 1542481.19393 / 3600 * T2000) / Ct1 : uranus = uranus - Y * Int(uranus / Y)
    neptune = ((304 + 20 / 60 + 55.19575 / 3600) + 786550.32074 / 3600 * T2000) / Ct1 : neptune = neptune - Y * Int(neptune / Y)
    a1 = (119.75 + 131.849 * T2000) / Ct1
    a2 = (53.09 + 479264.29 * T2000) / Ct1
    a3 = (313.45 + 481266.484 * T2000) / Ct1
    Om = (125.044555 - 1934.1361849 * T2000 + 0.0020762 * T2_2000 + T3_2000 / 467410 - T4_2000 / 60616000) / Ct1
    Longitude_noeud = Om
    l = (218.3164591 + 481267.88134236 * T2000 - 0.0013268 * T2_2000 + T3_2000 / 538841 - T4_2000 / 65194000) / Ct1
    l = l - Y * Int(l / Y) : W1 = l
    m = (357.5291092 + 35999.0502909 * T2000 - 0.0001536 * T2_2000 + T3_2000 / 24490000) / Ct1
    l_prime = m : Anomalie_lune = m
    f = (93.2720993 + 483202.0175273 * T2000 - 0.0034029 * T2_2000 - T3_2000 / 3526000 + T4_2000 / 863310000) / Ct1
    f = f - Y * Int(f / Y)
    n = (134.9634114 + 477198.8676313 * T2000 + 0.008997 * T2_2000 + T3_2000 / 69699 - T4_2000 / 14712000) / Ct1
    n = n - Y * Int(n / Y) : petit_l = n
    d = (297.8502042 + 445267.1115168 * T2000 - 0.00163 * T2_2000 + T3_2000 / 545868 - T4_2000 / 113065000) / Ct1
    d = d - Y * Int(d / Y) : dzeta_lune = W1 + 5029.0966 / 3600 / Ct1 * T2000
    Nutation() : nutation_en_obliquite = nu / 10000
    Obliquite = (23 + 26 / 60 + 21.448 / 3600 - 46.815 / 3600 * T2000 - 0.00059 / 3600 * T2_2000 + 0.001813 / 3600 * T3_2000) / Ct1 + nutation_en_obliquite * Ct
    Corrections_Un() : l = l + Correction / 3600 / Ct1 + nutation_en_longitude * Ct
    longitude = l : longitude_lune = l
    l1 = l * Ct1 : d1 = ((l1 - Int(l1)) * 60) : d2 = ((d1 - Int(d1)) * 60)
' ------------------------------------------------------------------------------
    tex$ =  tex$ + chr$(13) + "Longitude  =  " + str$(Int(l1)) + "  " + str$(Int(d1)) + " ' " + str$(Int(d2 * 100 + 0.5) / 100) + " '' "
' ------------------------------------------------------------------------------
    Corrections_Deux()
    b1 = Abs(b * Ct1) : d1 = ((b1 - Int(b1)) * 60) : d2 = ((d1 - Int(d1)) * 60)
    If (b < 0) Then Signe$ = "-" : Else : Signe$ = "+"
' ------------------------------------------------------------------------------
    tex$ =  tex$ + chr$(13) + "Latitude = " + Signe$ + str$(Int(b1)) + "" + str$(Int(d1)) + "'" + str$(Int(d2 * 100 + 0.5) / 100) + "''"
' ------------------------------------------------------------------------------
    Distance_terre_Lune() : distance_terre = p
' ------------------------------------------------------------------------------
    tex$ =  tex$ + chr$(13) + "Distance Terre - Lune  =  " + str$(int(distance_terre * 1000 + 0.5) / 1000) + " kms"
' ------------------------------------------------------------------------------
    p = Sin(6378.136 / distance_terre) * Ct1 * 3600 : p = Int(p * 1000 + 0.5) / 1000
    p1 = Int(p / 60)
' ------------------------------------------------------------------------------
    tex$ =  tex$ + chr$(13) +"Parallaxe  =  " +str$(p1)+" ' " + str$(Int((p - p1 * 60) * 1000 + 0.5) / 1000) + " '' "
' ------------------------------------------------------------------------------
    ascension = Ct1 / 15 * Atn((Cos(Obliquite) * Sin(longitude) - Tan(latitude) * Sin(Obliquite)) / Cos(longitude))
    If (ascension < 0) Then ascension = ascension + 24
    If (Cos(longitude) < 0) Then ascension = ascension + 12
    If (ascension > 24) Then ascension = ascension - 24
    Bidouille = Sin(latitude) * Cos(Obliquite) + Cos(latitude) * Sin(Obliquite) * Sin(longitude)
    Bidouille = Atn(Bidouille / Sqr(0-Bidouille * Bidouille + 1))
    declinaison = Ct1 * Bidouille
    d1 = ((ascension - Int(ascension)) * 60) : d2 = ((d1 - Int(d1)) * 60)
' ------------------------------------------------------------------------------
    tex$ = tex$ + chr$(13) + "Ascension droite  =  " +str$( Int(ascension)) + " h " + str$(Int(d1))+ " m " +str$( Int(d2 * 100 + 0.5) / 100) + " s"
' ------------------------------------------------------------------------------
    d = Abs(declinaison) : d1 = ((d - Int(d)) * 60) : d2 = ((d1 - Int(d1)) * 60)
    If (declinaison < 0) Then Signe$ = "-" :Else: Signe$ = "+"
' ------------------------------------------------------------------------------
    tex$ = tex$ + chr$(13) + "Dclinaison = " + Signe$ + str$(Int(d))+ "  " + str$(Int(d1)) + " ' " + str$(Int(d2 * 100 + 0.5) / 100) + " ''"
' ------------------------------------------------------------------------------
    Bidouille = Cos(latitude_lune) * Cos(longitude_lune - longitude_soleil)
    Bidouille = Atn(0-Bidouille / Sqr(0-Bidouille * Bidouille + 1)) + 2 * Atn(1)
    d1 = Bidouille : If (d1 < 0) Then d1 = d1 + PI
    p = 180 - d1 * Ct1 - 0.1468 * Sin(d1) * ((1 - 0.0549 * Sin(Anomalie_lune)) / (1 - 0.0167 * Sin(anomalie_soleil)))
    p = p / Ct1
    If (((longitude_lune<longitude_soleil)And((longitude_soleil-longitude_lune)<PI))Or((longitude_lune>longitude_soleil)And((longitude_lune-longitude_soleil)>PI)))
        elongation_lune$ = " Ouest"
    Else
        elongation_lune$ = " Est"
    end_if
' ------------------------------------------------------------------------------
    tex$ = tex$ + chr$(13) + "Elongation = " + str$(Int(d1 * Ct1 * 10 + 0.5) / 10) + "  " + elongation_lune$
' ------------------------------------------------------------------------------
    fraction_illuminee = 100 * Int(0.5 * (1 + Cos(p)) * 1000 + 0.5) / 1000
    fraction_illuminee = Int(fraction_illuminee * 100 + 0.5) / 100
' ------------------------------------------------------------------------------
    tex$ = tex$ + chr$(13) + "Phase de la Lune  =  " + str$(fraction_illuminee) + " %"
' ------------------------------------------------------------------------------
    
    message tex$
End_Sub
rem ============================================================================
' Cette SUB est pour le calcul de la position gocentrique de la Lune Position_Lune()
' La nutation est un balancement priodique de l'axe de rotation de la Terre
' autour de sa position moyenne
SUB Nutation()
    nu = (-171996 - 174.2 * T2000) * Sin(Om)
    nu = nu + (-13187 - 1.6 * T2000) * Sin(-2 * d + 2 * f + 2 * Om)
    nu = nu + (-2274 - 0.2 * T2000) * Sin(2 * f + 2 * Om)
    nu = nu + (2062 + 0.2 * T2000) * Sin(2 * Om)
    nu = nu + (1426 - 3.4 * T2000) * Sin(m)
    nu = nu + (712 + 0.1 * T2000) * Sin(n)
    nu = nu + (-517 + 1.2 * T2000) * Sin(-2 * d + m + 2 * f + 2 * Om)
    nu = nu + (-386 - 0.4 * T2000) * Sin(2 * f + Om)
    nu = nu - 301 * Sin(n + 2 * f + 2 * Om)
    nu = nu + (217 - 0.5 * T2000) * Sin(-2 * d - m + 2 * f + 2 * Om)
    nu = nu - 158 * Sin(-2 * d + n)
    nu = nu + (129 + 0.1 * T2000) * Sin(-2 * d + 2 * f + Om)
    nu = nu + 123 * Sin(0-n + 2 * f + 2 * Om)
    nu = nu + 63 * Sin(2 * d)
    nu = nu + (63 + 0.1 * T2000) * Sin(n + Om)
    nu = nu - 59 * Sin(2 * d - n + 2 * f + 2 * Om)
    nu = nu - (58 - 0.1 * T2000) * Sin(0-n + Om)
    nu = nu - 51 * Sin(n + 2 * f + Om)
    nu = nu + 48 * Sin(-2 * d + 2 * n)
    nu = nu + 46 * Sin(-2 * n + 2 * f + Om)
    nu = nu - 38 * Sin(2 * (d + f + Om))
    nu = nu - 31 * Sin(2 * (n + f + Om))
    nu = nu + 29 * Sin(2 * n)
    nu = nu + 29 * Sin(-2 * d + n + 2 * f + 2 * Om)
    nu = nu + 26 * Sin(2 * f)
    nu = nu - 22 * Sin(-2 * d + 2 * f)
    nu = nu + 21 * Sin(0-n + 2 * f + Om)
    nu = nu + (17 - 0.1 * T2000) * Sin(2 * m)
    nu = nu + 16 * Sin(2 * d - n + Om)
    nu = nu - (16 + 0.1 * T2000) * Sin(-2 * d + 2 * m + 2 * f + 2 * Om)
    nu = nu - 15 * Sin(m + Om)
    nu = nu - 13 * Sin(-2 * d + n + Om)
    nu = nu - 12 * Sin(0-m - Om)
    nu = nu + 11 * Sin(2 * n - 2 * f)
    nu = nu - 10 * Sin(2 * d - n + 2 * f + Om)
    nu = nu - 8 * Sin(2 * d + n + 2 * f + 2 * Om)
    nu = nu + 7 * Sin(m + 2 * f + 2 * Om)
    nu = nu - 7 * Sin(-2 * d + m + n)
    nu = nu - 7 * Sin(0-m + 2 * f + 2 * Om)
    nu = nu - 7 * Sin(2 * d + 2 * f + Om)
    nu = nu + 6 * Sin(2 * d + n)
    nu = nu + 6 * Sin(-2 * d + 2 * n + 2 * f + 2 * Om)
    nu = nu + 6 * Sin(-2 * d + n + 2 * f + Om)
    nu = nu - 6 * Sin(2 * d - 2 * n + Om)
    nu = nu - 6 * Sin(2 * d + Om)
    nu = nu + 5 * Sin(0-m + n)
    nu = nu - 5 * Sin(-2 * d - m + 2 * f + Om)
    nu = nu - 5 * Sin(-2 * d + Om)
    nu = nu - 5 * Sin(2 * n + 2 * f + Om)
    nu = nu + 4 * Sin(-2 * d + 2 * n + Om)
    nu = nu + 4 * Sin(-2 * d + m + 2 * f + Om)
    nu = nu + 4 * Sin(n - 2 * f)
    nu = nu - 4 * Sin(0-d + n)
    nu = nu - 4 * Sin(-2 * d + m)
    nu = nu - 4 * Sin(d)
    nu = nu + 3 * Sin(n + 2 * f)
    nu = nu - 3 * Sin(-2 * n + 2 * f + 2 * Om)
    nu = nu - 3 * Sin(0-d - m - n)
    nu = nu - 3 * Sin(m + n)
    nu = nu - 3 * Sin(0-m + n + 2 * f + 2 * Om)
    nu = nu - 3 * Sin(2 * d - m - n + 2 * f + 2 * Om)
    nu = nu - 3 * Sin(3 * n + 2 * f + 2 * Om)
    nu = nu - 3 * Sin(2 * d - m + 2 * f + 2 * Om)

    nutation_en_longitude = nu / 10000

    nu = (92025 + 8.9 * T2000) * Cos(Om)
    nu = nu + (5736 - 3.1 * T2000) * Cos(-2 * d + 2 * f + 2 * Om)
    nu = nu + (977 - 0.5 * T2000) * Cos(2 * f + 2 * Om)
    nu = nu + (-895 + 0.5 * T2000) * Cos(2 * Om)
    nu = nu + (54 - 0.1 * T2000) * Cos(m)
    nu = nu - 7 * Cos(n)
    nu = nu + (224 - 0.6 * T2000) * Cos(-2 * d + m + 2 * f + 2 * Om)
    nu = nu + 200 * Cos(2 * f + Om)
    nu = nu + (129 - 0.1 * T2000) * Cos(n + 2 * f + 2 * Om)
    nu = nu + (-95 + 0.3 * T2000) * Cos(-2 * d - m + 2 * f + 2 * Om)
    nu = nu - 70 * Cos(-2 * d + 2 * f + Om)
    nu = nu - 53 * Cos(0-n + 2 * f + 2 * Om)
    nu = nu - 33 * Cos(n + Om)
    nu = nu + 26 * Cos(2 * d - n + 2 * f + 2 * Om)
    nu = nu + 32 * Cos(0-n + Om)
    nu = nu + 27 * Cos(n + 2 * f + Om)
    nu = nu - 24 * Cos(-2 * n + 2 * f + Om)
    nu = nu + 16 * Cos(2 * (d + f + Om))
    nu = nu + 13 * Cos(2 * (n + f + Om))
    nu = nu - 12 * Cos(-2 * d + n + 2 * f + 2 * Om)
    nu = nu - 10 * Cos(0-n + 2 * f + Om)
    nu = nu - 8 * Cos(2 * d - n + Om)
    nu = nu + 7 * Cos(-2 * d + 2 * m + 2 * f + 2 * Om)
    nu = nu + 9 * Cos(m + Om)
    nu = nu + 7 * Cos(-2 * d + n + Om)
    nu = nu + 6 * Cos(0-m + Om)
    nu = nu + 5 * Cos(2 * d - n + 2 * f + Om)
    nu = nu + 3 * Cos(2 * d + n + 2 * f + 2 * Om)
    nu = nu - 3 * Cos(m + 2 * f + 2 * Om)
    nu = nu + 3 * Cos(0-m + 2 * f + 2 * Om)
    nu = nu + 3 * Cos(2 * d + 2 * f + Om)
    nu = nu - 3 * Cos(-2 * d + 2 * n + 2 * f + 2 * Om)
    nu = nu - 3 * Cos(-2 * d + n + 2 * f + Om)
    nu = nu + 3 * Cos(2 * d - 2 * n + Om)
    nu = nu + 3 * Cos(2 * d + Om)
    nu = nu + 3 * Cos(-2 * d - m + 2 * f + Om)
    nu = nu + 3 * Cos(-2 * d + Om)
    nu = nu + 3 * Cos(2 * n + 2 * f + Om)
END_SUB
rem ============================================================================
' Cette SUB est pour le calcul de la position gocentrique de la Lune Position_Lune()
' Premire srie de corrections
SUB Corrections_Un()
    Correction = 22639.55 * Sin(n)
    Correction = Correction + 4586.43061 * Sin(2 * d - n)
    Correction = Correction + 2369.91227 * Sin(2 * d)
    Correction = Correction + 769.02326 * Sin(2 * n)
    Correction = Correction + 211.65487 * Sin(2 * d - 2 * n)
    Correction = Correction + 205.44315 * Sin(2 * d - m - n)
    Correction = Correction + 191.95575 * Sin(2 * d + n)
    Correction = Correction + 164.73458 * Sin(2 * d - m)
    Correction = Correction + 55.17801 * Sin(2 * d - 2 * f)
    Correction = Correction + 39.53393 * Sin(n - 2 * f)
    Correction = Correction + 38.42974 * Sin(4 * d - n)
    Correction = Correction + 36.12364 * Sin(3 * n)
    Correction = Correction + 30.77247 * Sin(4 * d - 2 * n)
    Correction = Correction + 17.95512 * Sin(d + m)
    Correction = Correction + 14.53078 * Sin(2 * d - m + n)
    Correction = Correction + 14.37964 * Sin(2 * d + 2 * n)
    Correction = Correction + 13.89903 * Sin(4 * d)
    Correction = Correction + 13.194 * Sin(2 * d - 3 * n)
    Correction = Correction + 8.60582 * Sin(2 * d - m - 2 * n)
    Correction = Correction + 8.05076 * Sin(2 * d - 2 * m)
    Correction = Correction + 7.37173 * Sin(2 * d - 2 * m - n)
    Correction = Correction + 4.37416 * Sin(4 * d - m - n)
    Correction = Correction + 2.73198 * Sin(4 * d - m - 2 * n)
    Correction = Correction + 2.48897 * Sin(2 * d + m - 2 * n)
    Correction = Correction + 2.14619 * Sin(2 * d - m - 2 * f)
    Correction = Correction + 1.97772 * Sin(4 * d + n)
    Correction = Correction + 1.93367 * Sin(4 * n)
    Correction = Correction + 1.87083 * Sin(4 * d - m)
    Correction = Correction + 1.26186 * Sin(d + m + n)
    Correction = Correction + 1.18682 * Sin(4 * d - 3 * n)
    Correction = Correction + 1.17704 * Sin(2 * d - m + 2 * n)
    Correction = Correction + 1.07773 * Sin(d + m - n)
    Correction = Correction + 1.05949 * Sin(2 * d + 3 * n)
    Correction = Correction + 0.94827 * Sin(2 * d - 4 * n)
    Correction = Correction + 0.75173 * Sin(2 * d - 2 * m + n)
    Correction = Correction + 0.57156 * Sin(6 * d - 2 * n)
    Correction = Correction + 0.47842 * Sin(2 * d - m - 3 * n)
    Correction = Correction + 0.42034 * Sin(4 * f)
    Correction = Correction + 0.41342 * Sin(m + 2 * f)
    Correction = Correction + 0.40423 * Sin(3 * d)
    Correction = Correction + 0.39451 * Sin(6 * d - n)
    Correction = Correction + 0.34966 * Sin(d + m - 2 * n)
    Correction = Correction + 0.33983 * Sin(2 * d - 3 * m)
    Correction = Correction + 0.30874 * Sin(4 * d - 2 * m - n)
    Correction = Correction + 0.30157 * Sin(m - n - 2 * f)
    Correction = Correction + 0.30086 * Sin(4 * d - n - 2 * f)
    Correction = Correction + 0.29422 * Sin(2 * d - 2 * m - 2 * n)
    Correction = Correction + 0.29255 * Sin(6 * d - 3 * n)
    Correction = Correction + 0.28251 * Sin(4 * d - m + n)
    Correction = Correction + 0.27377 * Sin(3 * d + m - n)
    Correction = Correction + 0.26338 * Sin(m + n + 2 * f)
    Correction = Correction + 0.25429 * Sin(d + 2 * f)
    Correction = Correction + 0.24697 * Sin(2 * d - 3 * m - n)
    Correction = Correction + 0.21853 * Sin(4 * d + 2 * n)
    Correction = Correction + 0.17903 * Sin(2 * d - n - 2 * f)
    Correction = Correction + 0.17624 * Sin(2 * d + m - 3 * n)
    Correction = Correction + 0.15781 * Sin(4 * d - 2 * m - 2 * n)
    Correction = Correction + 0.15227 * Sin(4 * d - 2 * m)
    Correction = Correction + 0.1499 * Sin(3 * d + m)
    Correction = Correction + 0.12616 * Sin(6 * d)
    Correction = Correction + 0.111 * Sin(5 * n)
    Correction = Correction + 0.09982 * Sin(4 * d - m - 3 * n)
    Correction = Correction + 0.0932 * Sin(2 * d - m + 3 * n)
    Correction = Correction + 0.09205 * Sin(d + m + 2 * n)
    Correction = Correction + 0.09092 * Sin(n + 4 * f)
    Correction = Correction + 0.09033 * Sin(6 * d - m - 2 * n)
    Correction = Correction + 0.08472 * Sin(2 * d + m + n - 2 * f)
    Correction = Correction + 0.07765 * Sin(2 * d + 4 * n)
    Correction = Correction + 0.07501 * Sin(m - 2 * f)
    Correction = Correction + 0.07142 * Sin(6 * d - m - n)
    Correction = Correction + 0.0685 * Sin(2 * d - 5 * n)
    Correction = Correction + 0.06742 * Sin(2 * d + m - n + 2 * f)
    Correction = Correction + 0.06541 * Sin(2 * d + m + 2 * f)
    Correction = Correction + 0.06507 * Sin(3 * d - m)
    Correction = Correction + 0.06439 * Sin(2 * d - 2 * m + 2 * n)
    Correction = Correction + 0.06314 * Sin(2 * d - 2 * m - 2 * f)
    Correction = Correction + 0.05165 * Sin(m - 2 * n - 2 * f)
    Correction = Correction + 0.0445 * Sin(d + n + 2 * f)
    Correction = Correction + 0.04338 * Sin(m + 2 * n + 2 * f)
    Correction = Correction + 0.04304 * Sin(d - 2 * m)
    Correction = Correction + 0.039 * Sin(6 * d - m - 3 * n)
    Correction = Correction + 0.033 * Sin(2 * d - 3 * m + n)
    Correction = Correction + 0.03274 * Sin(4 * d - m + 2 * n)
    Correction = Correction + 0.02949 * Sin(2 * d - m - 4 * n)
    Correction = Correction + 0.02682 * Sin(4 * d + m - 3 * n)
    Correction = Correction + 0.02677 * Sin(m + 2 * n - 2 * f)
    Correction = Correction + 0.0251 * Sin(6 * d - m)
    Correction = Correction + 0.02429 * Sin(m - 2 * n + 2 * f)
    Correction = Correction + 0.02411 * Sin(4 * d - 2 * m + n)
    Correction = Correction + 0.02296 * Sin(d + m - 3 * n)
    Correction = Correction + 0.02289 * Sin(4 * d - m - n - 2 * f)
    Correction = Correction + 0.02285 * Sin(6 * d + n)
    Correction = Correction + 0.02244 * Sin(3 * d + m + n)
    Correction = Correction + 0.02149 * Sin(4 * d + 3 * n)
    Correction = Correction + 0.01993 * Sin(2 * d - n + 4 * f)
    Correction = Correction + 0.01819 * Sin(2 * d + m - 4 * n)
    Correction = Correction + 0.01741 * Sin(4 * d - 3 * m - n)
    Correction = Correction + 0.01605 * Sin(2 * d + m + n + 2 * f)
    Correction = Correction + 0.01598 * Sin(d - n + 2 * f)
    Correction = Correction + 0.01544 * Sin(2 * d - 2 * m - 3 * n)
    Correction = Correction + 0.01376 * Sin(6 * d - 4 * n)
    Correction = Correction + 0.01372 * Sin(2 * d + 4 * f)
    Correction = Correction + 0.01331 * Sin(2 * d - 4 * m)
    Correction = Correction + 0.01297 * Sin(2 * n + 4 * f)
    Correction = Correction + 0.01215 * Sin(3 * d - n + 2 * f)
    Correction = Correction + 0.00971 * Sin(4 * d - 3 * m)
    Correction = Correction + 0.00965 * Sin(2 * d - 3 * m - 2 * n)
    Correction = Correction + 0.00891 * Sin(3 * d + m - 2 * f)
    Correction = Correction + 0.00889 * Sin(2 * d + m + 2 * n - 2 * f)
    Correction = Correction + 0.00866 * Sin(8 * d - 2 * n)
    Correction = Correction + 0.0084 * Sin(8 * d - 3 * n)
    Correction = Correction + 0.00836 * Sin(6 * d - 2 * m - 2 * n)
    Correction = Correction + 0.00812 * Sin(2 * d - 4 * m - n)
    Correction = Correction + 0.00755 * Sin(4 * d - 3 * m - 2 * n)
    Correction = Correction + 0.00744 * Sin(6 * d - 2 * m - n)
    Correction = Correction + 0.0073 * Sin(2 * d - m + 4 * n)
    Correction = Correction + 0.00679 * Sin(d + m + 3 * n)
    Correction = Correction + 0.00666 * Sin(4 * d - m - 2 * f)
    Correction = Correction + 0.00665 * Sin(6 * n)
    Correction = Correction + 0.00662 * Sin(4 * d - 2 * n - 2 * f)
    Correction = Correction + 0.00623 * Sin(m - 3 * n - 2 * f)
    Correction = Correction + 0.00568 * Sin(2 * d + 5 * n)
    Correction = Correction + 0.0056 * Sin(4 * d - 2 * m - 3 * n)
    Correction = Correction + 0.0054 * Sin(d + 2 * n + 2 * f)
    Correction = Correction + 0.00538 * Sin(2 * d - 2 * m + 3 * n)
    Correction = Correction + 0.00526 * Sin(m + 3 * n + 2 * f)
    Correction = Correction + 0.00519 * Sin(2 * m + 2 * f)
    Correction = Correction + 0.00518 * Sin(3 * d - 2 * m)
    Correction = Correction + 0.00515 * Sin(2 * d + 2 * m - n + 2 * f)
    Correction = Correction + 0.00497 * Sin(2 * d - 6 * n)
    Correction = Correction + 0.00477 * Sin(6 * d - m + n)
    Correction = Correction + 0.00475 * Sin(5 * d + m - n)
    Correction = Correction + 0.00473 * Sin(2 * m - n - 2 * f)
    Correction = Correction + 0.00467 * Sin(2 * d - 3 * n + 2 * f)
    Correction = Correction + 0.00455 * Sin(8 * d - n)
    Correction = Correction + 0.00439 * Sin(5 * d)
    Correction = Correction + 0.00392 * Sin(5 * d + m - 2 * n)
    Correction = Correction + 0.00375 * Sin(3 * d + 2 * f)
    Correction = Correction + 0.00364 * Sin(6 * d - 2 * n - 2 * f)
    Correction = Correction + 0.00361 * Sin(d + 2 * m - 2 * n)
    Correction = Correction + 0.00353 * Sin(4 * d + m - n + 2 * f)
    Correction = Correction + 0.00344 * Sin(2 * d + n + 4 * f)
    Correction = Correction + 0.00336 * Sin(4 * d - m + 3 * n)
    Correction = Correction + 0.0033 * Sin(3 * d - m + n)
    Correction = Correction + 0.00324 * Sin(8 * d - 4 * n)
    Correction = Correction + 0.00318 * Sin(6 * d + 2 * n)
    Correction = Correction + 0.00312 * Sin(6 * d - 2 * m - 3 * n)
    Correction = Correction + 0.00298 * Sin(3 * d - 2 * n + 2 * f)
    Correction = Correction + 0.00295 * Sin(2 * d - 3 * m + 2 * n)
    Correction = Correction + 0.0029 * Sin(4 * d - 2 * m + 2 * n)
    Correction = Correction + 0.00289 * Sin(d - 2 * n - 2 * f)
    Correction = Correction + 0.00285 * Sin(6 * d - 2 * m)
    Correction = Correction + 0.00282 * Sin(2 * d - 2 * n + 4 * f)
    Correction = Correction + 0.0027 * Sin(2 * m + n + 2 * f)
    Correction = Correction + 0.00262 * Sin(2 * d + m + 2 * n + 2 * f)
    Correction = Correction + 0.00256 * Sin(3 * d + m + 2 * n)
    Correction = Correction + 0.00254 * Sin(d - 3 * m)
    Correction = Correction + 0.00229 * Sin(d - 2 * m - n)
    Correction = Correction + 0.0022 * Sin(4 * d + m - 2 * n + 2 * f)
    Correction = Correction + 0.00198 * Sin(2 * d + m - 4 * f)
    Correction = Correction + 0.00198 * Sin(4 * d + 4 * n)
    Correction = Correction + 0.00196 * Sin(8 * d - m - 2 * n)
    Correction = Correction + 0.00186 * Sin(4 * d + m + 2 * f)
    Correction = Correction + 0.00183 * Sin(4 * d + m + n - 2 * f)
    Correction = Correction + 0.00181 * Sin(5 * d + m)
    Correction = Correction + 0.00178 * Sin(2 * d - m - 5 * n)
    Correction = Correction + 0.00176 * Sin(6 * d - m - 4 * n)
    Correction = Correction + 0.00173 * Sin(2 * d + m - 5 * n)
    Correction = Correction + 0.0017 * Sin(8 * d - m - 3 * n)
    Correction = Correction + 0.00166 * Sin(m + 3 * n - 2 * f)
    Correction = Correction + 0.00163 * Sin(2 * d - 3 * m - 2 * f)
    Correction = Correction + 0.0016 * Sin(4 * d - 3 * m + n)
    Correction = Correction + 0.00155 * Sin(d - m + 2 * f)
    Correction = Correction + 0.00155 * Sin(d + m - 4 * n)
    Correction = Correction + 0.00153 * Sin(3 * n + 4 * f)
    Correction = Correction + 0.00139 * Sin(8 * d)
    Correction = Correction + 0.00133 * Sin(2 * d - 4 * m + n)
    Correction = Correction + 0.00123 * Sin(d - 4 * f)
    Correction = Correction + 0.00116 * Sin(3 * d + m - n - 2 * f)
    Correction = Correction + 0.00112 * Sin(8 * d - m - n)
    Correction = Correction + 0.00108 * Sin(4 * d - 2 * m - n - 2 * f)
    Correction = Correction + 0.00106 * Sin(m - 3 * n + 2 * f)
    Correction = Correction + 0.00102 * Sin(5 * d - m)
    Correction = Correction + 0.001 * Sin(2 * m - 2 * n - 2 * f)
    Correction = Correction + 0.00096 * Sin(2 * d + 2 * m + 2 * f)
    Correction = Correction - 666.44186 * Sin(m)
    Correction = Correction - 411.60287 * Sin(2 * f)
    Correction = Correction - 147.32654 * Sin(m - n)
    Correction = Correction - 124.98806 * Sin(d)
    Correction = Correction - 109.38419 * Sin(m + n)
    Correction = Correction - 45.10032 * Sin(n + 2 * f)
    Correction = Correction - 28.3981 * Sin(2 * d + m - n)
    Correction = Correction - 24.3591 * Sin(2 * d + m)
    Correction = Correction - 18.58467 * Sin(d - n)
    Correction = Correction - 9.67938 * Sin(m - 2 * n)
    Correction = Correction - 9.36601 * Sin(2 * d - n + 2 * f)
    Correction = Correction - 8.45308 * Sin(d + n)
    Correction = Correction - 7.63041 * Sin(m + 2 * n)
    Correction = Correction - 7.44804 * Sin(2 * m)
    Correction = Correction - 6.38325 * Sin(2 * d + n - 2 * f)
    Correction = Correction - 5.7417 * Sin(2 * d + 2 * f)
    Correction = Correction - 3.99767 * Sin(2 * n + 2 * f)
    Correction = Correction - 3.20968 * Sin(3 * d - n)
    Correction = Correction - 2.91464 * Sin(2 * d + m + n)
    Correction = Correction - 2.56813 * Sin(2 * m - n)
    Correction = Correction - 2.52138 * Sin(2 * d + 2 * m - n)
    Correction = Correction - 1.75296 * Sin(d - 2 * n)
    Correction = Correction - 1.43724 * Sin(2 * d + m - 2 * f)
    Correction = Correction - 1.37259 * Sin(2 * n - 2 * f)
    Correction = Correction - 1.22412 * Sin(3 * d - 2 * n)
    Correction = Correction - 1.16177 * Sin(2 * m + n)
    Correction = Correction - 0.99023 * Sin(2 * d + n + 2 * f)
    Correction = Correction - 0.6694 * Sin(m - 3 * n)
    Correction = Correction - 0.63523 * Sin(4 * d + m - n)
    Correction = Correction - 0.58399 * Sin(d + 2 * n)
    Correction = Correction - 0.58332 * Sin(d - 2 * f)
    Correction = Correction - 0.56065 * Sin(2 * d - 2 * n - 2 * f)
    Correction = Correction - 0.55694 * Sin(d - m)
    Correction = Correction - 0.54594 * Sin(m + 3 * n)
    Correction = Correction - 0.53572 * Sin(2 * d - 2 * n + 2 * f)
    Correction = Correction - 0.4538 * Sin(2 * d + 2 * n - 2 * f)
    Correction = Correction - 0.42624 * Sin(2 * d - m - n + 2 * f)
    Correction = Correction - 0.38215 * Sin(2 * d - m + 2 * f)
    Correction = Correction - 0.37453 * Sin(2 * d - m + n - 2 * f)
    Correction = Correction - 0.35759 * Sin(4 * d + m - 2 * n)
    Correction = Correction - 0.32866 * Sin(3 * n + 2 * f)
    Correction = Correction - 0.29023 * Sin(2 * d + m + 2 * n)
    Correction = Correction - 0.28911 * Sin(4 * d + m)
    Correction = Correction - 0.25304 * Sin(3 * d - 2 * f)
    Correction = Correction - 0.2499 * Sin(2 * d + 2 * m - 2 * n)
    Correction = Correction - 0.23141 * Sin(3 * d - m - n)
    Correction = Correction - 0.20134 * Sin(4 * d - n + 2 * f)
    Correction = Correction - 0.19311 * Sin(2 * m - 2 * n)
    Correction = Correction - 0.18576 * Sin(2 * d + 2 * m)
    Correction = Correction - 0.16977 * Sin(4 * d - 2 * n + 2 * f)
    Correction = Correction - 0.13636 * Sin(d - m - n)
    Correction = Correction - 0.12812 * Sin(d - 3 * n)
    Correction = Correction - 0.12386 * Sin(2 * d + 2 * n + 2 * f)
    Correction = Correction - 0.12073 * Sin(d - m + n)
    Correction = Correction - 0.10136 * Sin(3 * m)
    Correction = Correction - 0.09154 * Sin(2 * d - 3 * n - 2 * f)
    Correction = Correction - 0.085 * Sin(4 * d + 2 * f)
    Correction = Correction - 0.08311 * Sin(3 * d - m - 2 * n)
    Correction = Correction - 0.08282 * Sin(m + n - 2 * f)
    Correction = Correction - 0.08049 * Sin(m - n + 2 * f)
    Correction = Correction - 0.08019 * Sin(n - 4 * f)
    Correction = Correction - 0.07518 * Sin(2 * d - 4 * f)
    Correction = Correction - 0.07373 * Sin(2 * d - m + n + 2 * f)
    Correction = Correction - 0.06601 * Sin(4 * d + n - 2 * f)
    Correction = Correction - 0.06513 * Sin(2 * m + 2 * n)
    Correction = Correction - 0.06103 * Sin(2 * d - m - n - 2 * f)
    Correction = Correction - 0.05725 * Sin(5 * d - 2 * n)
    Correction = Correction - 0.05684 * Sin(3 * n - 2 * f)
    Correction = Correction - 0.05142 * Sin(3 * m - n)
    Correction = Correction - 0.0507 * Sin(4 * d + m + n)
    Correction = Correction - 0.04702 * Sin(m - 4 * n)
    Correction = Correction - 0.04442 * Sin(3 * d - 3 * n)
    Correction = Correction - 0.04189 * Sin(3 * d + m - 2 * n)
    Correction = Correction - 0.04074 * Sin(d + 3 * n)
    Correction = Correction - 0.04012 * Sin(d + n - 2 * f)
    Correction = Correction - 0.03968 * Sin(d + 2 * m)
    Correction = Correction - 0.03947 * Sin(m + 4 * n)
    Correction = Correction - 0.03587 * Sin(d + m + 2 * f)
    Correction = Correction - 0.03514 * Sin(4 * d + 2 * m - 2 * n)
    Correction = Correction - 0.03336 * Sin(2 * d + 3 * n - 2 * f)
    Correction = Correction - 0.02979 * Sin(3 * d - n - 2 * f)
    Correction = Correction - 0.02887 * Sin(2 * d - m + 2 * n - 2 * f)
    Correction = Correction - 0.02804 * Sin(2 * d - m - 2 * n - 2 * f)
    Correction = Correction - 0.02676 * Sin(2 * d + m + 3 * n)
    Correction = Correction - 0.02602 * Sin(4 * n + 2 * f)
    Correction = Correction - 0.02391 * Sin(4 * d - 2 * f)
    Correction = Correction - 0.02379 * Sin(d - n - 2 * f)
    Correction = Correction - 0.02349 * Sin(2 * d + 2 * m - 2 * f)
    Correction = Correction - 0.02273 * Sin(4 * d - m - n + 2 * f)
    Correction = Correction - 0.02171 * Sin(4 * d + 2 * m - n)
    Correction = Correction - 0.02157 * Sin(2 * d - m - 2 * n + 2 * f)
    Correction = Correction - 0.01948 * Sin(3 * d - m - 2 * f)
    Correction = Correction - 0.01875 * Sin(4 * d + m - n - 2 * f)
    Correction = Correction - 0.01816 * Sin(2 * d - 2 * m + 2 * f)
    Correction = Correction - 0.01796 * Sin(3 * m + n)
    Correction = Correction - 0.01781 * Sin(4 * d + n + 2 * f)
    Correction = Correction - 0.01686 * Sin(5 * d - 3 * n)
    Correction = Correction - 0.01644 * Sin(2 * d - 2 * m + n - 2 * f)
    Correction = Correction - 0.01541 * Sin(2 * d - 2 * m - n + 2 * f)
    Correction = Correction - 0.01533 * Sin(4 * d - m - 2 * n + 2 * f)
    Correction = Correction - 0.01514 * Sin(2 * m - 3 * n)
    Correction = Correction - 0.01483 * Sin(d - m + 2 * n)
    Correction = Correction - 0.0135 * Sin(5 * d - n)
    Correction = Correction - 0.01343 * Sin(2 * d + 2 * m + n)
    Correction = Correction - 0.01332 * Sin(2 * d + 3 * n + 2 * f)
    Correction = Correction - 0.01282 * Sin(6 * d + m - 2 * n)
    Correction = Correction - 0.01281 * Sin(d - m - 2 * f)
    Correction = Correction - 0.01182 * Sin(3 * d - 2 * m - n)
    Correction = Correction - 0.01114 * Sin(4 * d - m + 2 * f)
    Correction = Correction - 0.01077 * Sin(2 * d - 4 * n - 2 * f)
    Correction = Correction - 0.01064 * Sin(6 * d + m - n)
    Correction = Correction - 0.01062 * Sin(3 * d + n - 2 * f)
    Correction = Correction - 0.01007 * Sin(2 * d - m + 2 * n + 2 * f)
    Correction = Correction - 0.0098 * Sin(4 * d + 2 * n - 2 * f)
    Correction = Correction - 0.00955 * Sin(d - 4 * n)
    Correction = Correction - 0.00944 * Sin(2 * d + 2 * m - 3 * n)
    Correction = Correction - 0.00934 * Sin(4 * d - 3 * n + 2 * f)
    Correction = Correction - 0.0085 * Sin(2 * d - n - 4 * f)
    Correction = Correction - 0.00849 * Sin(d + 2 * m + n)
    Correction = Correction - 0.00732 * Sin(4 * d - m + n - 2 * f)
    Correction = Correction - 0.00694 * Sin(d - m - 2 * n)
    Correction = Correction - 0.00693 * Sin(5 * d - m - 2 * n)
    Correction = Correction - 0.00668 * Sin(4 * d + m + 2 * n)
    Correction = Correction - 0.00659 * Sin(d + m + n + 2 * f)
    Correction = Correction - 0.00654 * Sin(2 * d + 2 * m - n - 2 * f)
    Correction = Correction - 0.00623 * Sin(3 * d + m - 3 * n)
    Correction = Correction - 0.00509 * Sin(6 * d - 2 * n + 2 * f)
    Correction = Correction - 0.00478 * Sin(6 * d + m - 3 * n)
    Correction = Correction - 0.00434 * Sin(2 * d - 2 * m - n - 2 * f)
    Correction = Correction - 0.00431 * Sin(4 * d - 5 * n)
    Correction = Correction - 0.00416 * Sin(3 * m - 2 * n)
    Correction = Correction - 0.00399 * Sin(3 * d - 2 * m - 2 * n)
    Correction = Correction - 0.00396 * Sin(6 * d + m)
    Correction = Correction - 0.00389 * Sin(3 * d + 2 * n)
    Correction = Correction - 0.00378 * Sin(2 * d - 2 * m + n + 2 * f)
    Correction = Correction - 0.00369 * Sin(4 * d + 2 * m - 3 * n)
    Correction = Correction - 0.00365 * Sin(2 * d - m - 3 * n - 2 * f)
    Correction = Correction - 0.00359 * Sin(6 * d - n + 2 * f)
    Correction = Correction - 0.00355 * Sin(2 * m - 2 * f)
    Correction = Correction - 0.00354 * Sin(4 * n - 2 * f)
    Correction = Correction - 0.00346 * Sin(2 * d + m - 2 * n - 2 * f)
    Correction = Correction - 0.00341 * Sin(2 * m + 3 * n)
    Correction = Correction - 0.00335 * Sin(5 * d - n - 2 * f)
    Correction = Correction - 0.00332 * Sin(m - 5 * n)
    Correction = Correction - 0.003 * Sin(d + 2 * m - n)
    Correction = Correction - 0.00297 * Sin(3 * d - m - 3 * n)
    Correction = Correction - 0.00287 * Sin(m + 5 * n)
    Correction = Correction - 0.00287 * Sin(6 * d - 3 * n + 2 * f)
    Correction = Correction - 0.00286 * Sin(2 * d - m - 4 * f)
    Correction = Correction - 0.00285 * Sin(d + 4 * n)
    Correction = Correction - 0.00274 * Sin(4 * d + 2 * n + 2 * f)
    Correction = Correction - 0.00251 * Sin(4 * d - m + n + 2 * f)
    Correction = Correction - 0.00247 * Sin(2 * d + 4 * n - 2 * f)
    Correction = Correction - 0.00236 * Sin(2 * d + m + 4 * n)
    Correction = Correction - 0.00232 * Sin(2 * d - m + 3 * n - 2 * f)
    Correction = Correction - 0.00228 * Sin(2 * d + m - n - 2 * f)
    Correction = Correction - 0.00214 * Sin(6 * d - 2 * f)
    Correction = Correction - 0.00212 * Sin(d - m + n - 2 * f)
    Correction = Correction - 0.00208 * Sin(4 * d + 2 * m)
    Correction = Correction - 0.00201 * Sin(5 * n + 2 * f)
    Correction = Correction - 0.002   * Sin(2 * d + 2 * m + n - 2 * f)
    Correction = Correction - 0.00191 * Sin(3 * d + 2 * m)
    Correction = Correction - 0.00189 * Sin(3 * d - m - n - 2 * f)
    Correction = Correction - 0.00189 * Sin(5 * d - m - 3 * n)
    Correction = Correction - 0.00188 * Sin(2 * d + 3 * m - n)
    Correction = Correction - 0.00174 * Sin(3 * d - 4 * n)
    Correction = Correction - 0.0016  * Sin(4 * d - 2 * m - n + 2 * f)
    Correction = Correction - 0.00157 * Sin(d + m + n - 2 * f)
    Correction = Correction - 0.00154 * Sin(5 * d - m - n)
    Correction = Correction - 0.00149 * Sin(d - m + 3 * n)
    Correction = Correction - 0.00142 * Sin(d - 2 * n + 2 * f)
    Correction = Correction - 0.00138 * Sin(3 * d + m - n + 2 * f)
    Correction = Correction - 0.00137 * Sin(5 * d - 2 * f)
    Correction = Correction - 0.00133 * Sin(2 * d - 2 * m + 2 * n - 2 * f)
    Correction = Correction - 0.00132 * Sin(6 * d + 2 * f)
    Correction = Correction - 0.00131 * Sin(2 * d + 4 * n + 2 * f)
    Correction = Correction - 0.00128 * Sin(4 * m)
    Correction = Correction - 0.00127 * Sin(3 * d + 2 * m - n)
    Correction = Correction - 0.00121 * Sin(4 * d - m + 2 * n - 2 * f)
    Correction = Correction - 0.00119 * Sin(2 * m - 4 * n)
    Correction = Correction - 0.00117 * Sin(2 * d - m + 3 * n + 2 * f)
    Correction = Correction - 0.00116 * Sin(2 * d + m - 3 * n - 2 * f)
    Correction = Correction - 0.00111 * Sin(2 * d - 2 * m - 2 * n - 2 * f)
    Correction = Correction - 0.00111 * Sin(2 * d - 5 * n - 2 * f)
    Correction = Correction - 0.00109 * Sin(4 * d + 3 * n - 2 * f)
    Correction = Correction - 0.00108 * Sin(4 * m - n)
    Correction = Correction - 0.00102 * Sin(d + 2 * m + 2 * n)
    Correction = Correction - 0.00102 * Sin(3 * d - 2 * m - 2 * f)
    Correction = Correction - 0.001 * Sin(d - m - n - 2 * f)
    Correction = Correction - 0.00098 * Sin(7 * d - 3 * n)
    Correction = Correction + 14.2488 * Sin(18 * venus - 16 * longitude_moyenne_terre - n + 26.54261 / Ct1)
    Correction = Correction + 1.1431 * Sin(2 * longitude_moyenne_terre - 2 * jupiter + 2 * d - n + 180.11977 / Ct1)
    Correction = Correction + 0.9011 * Sin(4 * longitude_moyenne_terre - 8 * mars + 3 * jupiter + 285.98707 / Ct1)
    Correction = Correction + 0.8216 * Sin(venus - longitude_moyenne_terre + 180.00988 / Ct1)
    Correction = Correction + 0.7881 * Sin(18 * venus - 16 * longitude_moyenne_terre - 2 * n + 26.54324 / Ct1)
    Correction = Correction + 0.7393 * Sin(18 * venus - 16 * longitude_moyenne_terre + 26.5456 / Ct1)
    Correction = Correction + 0.6437 * Sin(3 * venus - 3 * longitude_moyenne_terre + 2 * d - n + 179.98144 / Ct1)
    Correction = Correction + 0.6388 * Sin(longitude_moyenne_terre - jupiter + 1.2289 / Ct1)
    Correction = Correction + 0.5634 * Sin(10 * venus - 3 * longitude_moyenne_terre - n + 333.30551 / Ct1)
    Correction = Correction + 0.4453 * Sin(2 * longitude_moyenne_terre - 3 * jupiter + 2 * d - n + 10.07001 / Ct1)
    Correction = Correction + 0.3436 * Sin(2 * venus - 3 * longitude_moyenne_terre + 269.95393 / Ct1)
    Correction = Correction + 0.3246 * Sin(longitude_moyenne_terre - 2 * mars + 318.13776 / Ct1)
    Correction = Correction + 0.3016 * Sin(2 * venus - 2 * longitude_moyenne_terre + 0.20448 / Ct1)
    Correction = Correction + 7.06304 * Sin(dzeta_lune - f + 0.00094 / Ct1)
    Correction = Correction + 0.49331 * Sin(dzeta_lune + petit_l - f + 0.00127 / Ct1)
    Correction = Correction + 0.49141 * Sin(dzeta_lune - petit_l - f + 0.00127 / Ct1)
    Correction = Correction + 0.36061 * Sin(dzeta_lune + f + 0.00071 / Ct1)
    Correction = Correction + 0.09642 * Sin(dzeta_lune + 2 * d - f + 0.0009 / Ct1)
    Correction = Correction + 0.06569 * Sin(dzeta_lune - 2 * d - f + 0.001 / Ct1)
    Correction = Correction + 0.06456 * Sin(dzeta_lune + 2 * d - petit_l - f + 0.00042 / Ct1)
    Correction = Correction + 0.05036 * Sin(dzeta_lune - petit_l + f + 0.00051 / Ct1)
    Correction = Correction + 0.04962 * Sin(dzeta_lune - 2 * d + petit_l - f + 0.00029 / Ct1)
    Correction = Correction + 0.04746 * Sin(dzeta_lune - 2 * d + f + 0.00076 / Ct1)
    Correction = Correction + 0.03838 * Sin(dzeta_lune + petit_l + f + 0.0007 / Ct1)
    Correction = Correction + 0.03638 * Sin(2 * dzeta_lune - 2 * f + 180 / Ct1)
    Correction = Correction + 0.03402 * Sin(dzeta_lune + 2 * petit_l - f + 0.00126 / Ct1)
    Correction = Correction + 0.03279 * Sin(dzeta_lune - 2 * petit_l - f + 0.00128 / Ct1)
    Correction = Correction + 0.02206 * Sin(2 * d - petit_l)
    Correction = Correction + 0.01492 * Sin(dzeta_lune - 3 * f + 180.00086 / Ct1)
    Correction = Correction + 0.01234 * Sin(dzeta_lune + 2 * d + petit_l - f + 0.00102 / Ct1)
END_SUB
rem ============================================================================
' Cette SUB est pour le calcul de la position gocentrique de la Lune Position_Lune()
' Deuxime srie de corrections
Sub Corrections_Deux()
    Correction = 18461.4 * Sin(f)
    Correction = Correction - 6.29664 * Sin(3 * f)
    Correction = Correction + 2.79871 * Sin(n - 3 * f)
    Correction = Correction + 999.70079 * Sin(n - f)
    Correction = Correction + 1010.1743 * Sin(n + f)
    Correction = Correction - 1.01941 * Sin(n + 3 * f)
    Correction = Correction - 0.13035 * Sin(2 * n - 3 * f)
    Correction = Correction + 31.75985 * Sin(2 * n - f)
    Correction = Correction + 61.91229 * Sin(2 * n + f)
    Correction = Correction - 0.11787 * Sin(2 * n + 3 * f)
    Correction = Correction + 1.58131 * Sin(3 * n - f)
    Correction = Correction + 3.98407 * Sin(3 * n + f)
    Correction = Correction - 0.01181 * Sin(3 * n + 3 * f)
    Correction = Correction + 0.09157 * Sin(4 * n - f)
    Correction = Correction + 0.26325 * Sin(4 * n + f)
    Correction = Correction + 0.01768 * Sin(5 * n + f)
    Correction = Correction - 0.07479 * Sin(m - 3 * n - f)
    Correction = Correction - 0.02365 * Sin(m - 3 * n + f)
    Correction = Correction - 0.79322 * Sin(m - 2 * n - f)
    Correction = Correction - 0.30129 * Sin(m - 2 * n + f)
    Correction = Correction - 6.73173 * Sin(m - n - f)
    Correction = Correction - 5.6326 * Sin(m - n + f)
    Correction = Correction - 4.83983 * Sin(m - f)
    Correction = Correction - 6.46036 * Sin(m + f)
    Correction = Correction + 0.01157 * Sin(m + 3 * f)
    Correction = Correction - 5.07614 * Sin(m + n - f)
    Correction = Correction - 5.31151 * Sin(m + n + f)
    Correction = Correction - 0.31292 * Sin(m + 2 * n - f)
    Correction = Correction - 0.63884 * Sin(m + 2 * n + f)
    Correction = Correction - 0.02419 * Sin(m + 3 * n - f)
    Correction = Correction - 0.06176 * Sin(m + 3 * n + f)
    Correction = Correction - 0.01571 * Sin(2 * m - 2 * n - f)
    Correction = Correction - 0.11335 * Sin(2 * m - n - f)
    Correction = Correction - 0.09511 * Sin(2 * m - n + f)
    Correction = Correction - 0.01801 * Sin(2 * m - f)
    Correction = Correction - 0.05729 * Sin(2 * m + f)
    Correction = Correction - 0.06187 * Sin(2 * m + n - f)
    Correction = Correction - 0.05504 * Sin(2 * m + n + f)
    Correction = Correction + 0.01031 * Sin(d - m - n - f)
    Correction = Correction - 0.01346 * Sin(d - m - f)
    Correction = Correction - 0.01829 * Sin(d - m + f)
    Correction = Correction - 0.02012 * Sin(d - m + n - f)
    Correction = Correction - 0.01255 * Sin(d - 3 * n - f)
    Correction = Correction - 0.10964 * Sin(d - 2 * n - f)
    Correction = Correction - 0.07846 * Sin(d - 2 * n + f)
    Correction = Correction - 0.42989 * Sin(d - n - f)
    Correction = Correction + 0.13928 * Sin(d - n + f)
    Correction = Correction - 0.03226 * Sin(d - 3 * f)
    Correction = Correction - 4.80578 * Sin(d - f)
    Correction = Correction - 5.36844 * Sin(d + f)
    Correction = Correction - 0.58893 * Sin(d + n - f)
    Correction = Correction - 0.66741 * Sin(d + n + f)
    Correction = Correction - 0.03636 * Sin(d + 2 * n - f)
    Correction = Correction - 0.06383 * Sin(d + 2 * n + f)
    Correction = Correction + 0.01597 * Sin(d + m - 2 * n - f)
    Correction = Correction + 0.0168 * Sin(d + m - 2 * n + f)
    Correction = Correction - 0.0559 * Sin(d + m - n + f)
    Correction = Correction + 0.80426 * Sin(d + m - f)
    Correction = Correction + 0.80263 * Sin(d + m + f)
    Correction = Correction + 0.03465 * Sin(d + m + n - f)
    Correction = Correction + 0.10176 * Sin(d + m + n + f)
    Correction = Correction + 0.01016 * Sin(d + m + 2 * n + f)
    Correction = Correction + 0.01042 * Sin(2 * d - 3 * m - n + f)
    Correction = Correction + 0.03647 * Sin(2 * d - 3 * m - f)
    Correction = Correction + 0.01603 * Sin(2 * d - 3 * m + f)
    Correction = Correction + 0.02285 * Sin(2 * d - 2 * m - 2 * n - f)
    Correction = Correction + 0.26865 * Sin(2 * d - 2 * m - n - f)
    Correction = Correction + 0.31474 * Sin(2 * d - 2 * m - n + f)
    Correction = Correction + 1.08587 * Sin(2 * d - 2 * m - f)
    Correction = Correction + 0.38353 * Sin(2 * d - 2 * m + f)
    Correction = Correction + 0.06915 * Sin(2 * d - 2 * m + n - f)
    Correction = Correction + 0.05848 * Sin(2 * d - 2 * m + n + f)
    Correction = Correction + 0.05502 * Sin(2 * d - m - 3 * n - f)
    Correction = Correction + 0.65025 * Sin(2 * d - m - 2 * n - f)
    Correction = Correction - 0.06208 * Sin(2 * d - m - 2 * n + f)
    Correction = Correction + 0.01034 * Sin(2 * d - m - n - 3 * f)
    Correction = Correction + 7.43488 * Sin(2 * d - m - n - f)
    Correction = Correction + 8.86853 * Sin(2 * d - m - n + f)
    Correction = Correction - 0.01177 * Sin(2 * d - m - n + 3 * f)
    Correction = Correction + 0.08815 * Sin(2 * d - m - 3 * f)
    Correction = Correction + 29.57794 * Sin(2 * d - m - f)
    Correction = Correction + 7.95891 * Sin(2 * d - m + f)
    Correction = Correction - 0.01669 * Sin(2 * d - m + n - 3 * f)
    Correction = Correction + 1.76606 * Sin(2 * d - m + n - f)
    Correction = Correction + 1.13466 * Sin(2 * d - m + n + f)
    Correction = Correction + 0.12897 * Sin(2 * d - m + 2 * n - f)
    Correction = Correction + 0.12387 * Sin(2 * d - m + 2 * n + f)
    Correction = Correction + 0.01211 * Sin(2 * d - m + 3 * n + f)
    Correction = Correction + 0.01127 * Sin(2 * d - 5 * n - f)
    Correction = Correction + 0.13381 * Sin(2 * d - 4 * n - f)
    Correction = Correction + 0.02496 * Sin(2 * d - 4 * n + f)
    Correction = Correction + 1.51564 * Sin(2 * d - 3 * n - f)
    Correction = Correction + 0.25408 * Sin(2 * d - 3 * n + f)
    Correction = Correction + 0.02045 * Sin(2 * d - 2 * n - 3 * f)
    Correction = Correction + 15.56635 * Sin(2 * d - 2 * n - f)
    Correction = Correction - 1.62443 * Sin(2 * d - 2 * n + f)
    Correction = Correction - 0.06561 * Sin(2 * d - 2 * n + 3 * f)
    Correction = Correction + 0.32907 * Sin(2 * d - n - 3 * f)
    Correction = Correction + 166.57528 * Sin(2 * d - n - f)
    Correction = Correction + 199.48515 * Sin(2 * d - n + f)
    Correction = Correction - 0.24484 * Sin(2 * d - n + 3 * f)
    Correction = Correction + 2.18637 * Sin(2 * d - 3 * f)
    Correction = Correction + 623.65783 * Sin(2 * d - f)
    Correction = Correction + 117.26161 * Sin(2 * d + f)
    Correction = Correction - 0.14453 * Sin(2 * d + 3 * f)
    Correction = Correction - 0.29116 * Sin(2 * d + n - 3 * f)
    Correction = Correction + 33.35743 * Sin(2 * d + n - f)
    Correction = Correction + 15.12165 * Sin(2 * d + n + f)
    Correction = Correction - 0.03038 * Sin(2 * d + n + 3 * f)
    Correction = Correction + 2.14618 * Sin(2 * d + 2 * n - f)
    Correction = Correction + 1.51976 * Sin(2 * d + 2 * n + f)
    Correction = Correction + 0.14642 * Sin(2 * d + 3 * n - f)
    Correction = Correction + 0.13795 * Sin(2 * d + 3 * n + f)
    Correction = Correction + 0.01027 * Sin(2 * d + 4 * n - f)
    Correction = Correction + 0.01186 * Sin(2 * d + 4 * n + f)
    Correction = Correction + 0.01818 * Sin(2 * d + m - 3 * n - f)
    Correction = Correction + 0.07913 * Sin(2 * d + m - 2 * n - f)
    Correction = Correction + 0.05429 * Sin(2 * d + m - 2 * n + f)
    Correction = Correction - 0.79105 * Sin(2 * d + m - n - f)
    Correction = Correction - 1.31788 * Sin(2 * d + m - n + f)
    Correction = Correction - 0.05457 * Sin(2 * d + m - 3 * f)
    Correction = Correction - 12.0947 * Sin(2 * d + m - f)
    Correction = Correction - 1.26433 * Sin(2 * d + m + f)
    Correction = Correction - 0.82275 * Sin(2 * d + m + n - f)
    Correction = Correction - 0.23702 * Sin(2 * d + m + n + f)
    Correction = Correction - 0.06283 * Sin(2 * d + m + 2 * n - f)
    Correction = Correction - 0.03142 * Sin(2 * d + m + 2 * n + f)
    Correction = Correction - 0.01262 * Sin(2 * d + 2 * m - 2 * n - f)
    Correction = Correction - 0.10535 * Sin(2 * d + 2 * m - n - f)
    Correction = Correction - 0.1133 * Sin(2 * d + 2 * m - n + f)
    Correction = Correction - 0.13415 * Sin(2 * d + 2 * m - f)
    Correction = Correction - 0.01482 * Sin(2 * d + 2 * m + f)
    Correction = Correction - 0.02104 * Sin(3 * d - m - n - f)
    Correction = Correction - 0.01356 * Sin(3 * d - m - n + f)
    Correction = Correction - 0.02572 * Sin(3 * d - m - f)
    Correction = Correction - 0.03941 * Sin(3 * d - 2 * n - f)
    Correction = Correction - 0.04852 * Sin(3 * d - 2 * n + f)
    Correction = Correction - 0.30517 * Sin(3 * d - n - f)
    Correction = Correction - 0.20593 * Sin(3 * d - n + f)
    Correction = Correction - 0.01009 * Sin(3 * d - 3 * f)
    Correction = Correction - 0.35183 * Sin(3 * d - f)
    Correction = Correction - 0.0284 * Sin(3 * d + f)
    Correction = Correction - 0.03611 * Sin(3 * d + n - f)
    Correction = Correction + 0.01321 * Sin(3 * d + m - n - f)
    Correction = Correction + 0.02083 * Sin(3 * d + m - n + f)
    Correction = Correction + 0.03436 * Sin(3 * d + m - f)
    Correction = Correction + 0.01351 * Sin(3 * d + m + f)
    Correction = Correction + 0.0123 * Sin(4 * d - 2 * m - 2 * n + f)
    Correction = Correction + 0.03462 * Sin(4 * d - 2 * m - n - f)
    Correction = Correction + 0.0238 * Sin(4 * d - 2 * m - n + f)
    Correction = Correction + 0.02899 * Sin(4 * d - 2 * m - f)
    Correction = Correction + 0.0127 * Sin(4 * d - 2 * m + f)
    Correction = Correction + 0.05251 * Sin(4 * d - m - 2 * n - f)
    Correction = Correction + 0.21376 * Sin(4 * d - m - 2 * n + f)
    Correction = Correction + 0.5958 * Sin(4 * d - m - n - f)
    Correction = Correction + 0.33882 * Sin(4 * d - m - n + f)
    Correction = Correction + 0.41496 * Sin(4 * d - m - f)
    Correction = Correction + 0.15791 * Sin(4 * d - m + f)
    Correction = Correction + 0.05686 * Sin(4 * d - m + n - f)
    Correction = Correction + 0.03009 * Sin(4 * d - m + n + f)
    Correction = Correction + 0.02174 * Sin(4 * d - 3 * n + f)
    Correction = Correction + 0.63371 * Sin(4 * d - 2 * n - f)
    Correction = Correction + 2.41389 * Sin(4 * d - 2 * n + f)
    Correction = Correction + 6.57962 * Sin(4 * d - n - f)
    Correction = Correction + 2.9985 * Sin(4 * d - n + f)
    Correction = Correction + 0.06257 * Sin(4 * d - 3 * f)
    Correction = Correction + 3.67449 * Sin(4 * d - f)
    Correction = Correction + 1.19188 * Sin(4 * d + f)
    Correction = Correction + 0.47338 * Sin(4 * d + n - f)
    Correction = Correction + 0.21259 * Sin(4 * d + n + f)
    Correction = Correction + 0.04834 * Sin(4 * d + 2 * n - f)
    Correction = Correction + 0.02828 * Sin(4 * d + 2 * n + f)
    Correction = Correction - 0.02957 * Sin(4 * d + m - 2 * n + f)
    Correction = Correction - 0.17191 * Sin(4 * d + m - n - f)
    Correction = Correction - 0.05097 * Sin(4 * d + m - n + f)
    Correction = Correction - 0.11308 * Sin(4 * d + m - f)
    Correction = Correction - 0.02549 * Sin(4 * d + m + f)
    Correction = Correction - 0.01692 * Sin(4 * d + m + n - f)
    Correction = Correction - 0.01049 * Sin(5 * d - n - f)
    Correction = Correction + 0.01091 * Sin(6 * d - m - 2 * n - f)
    Correction = Correction + 0.01486 * Sin(6 * d - m - n - f)
    Correction = Correction + 0.03118 * Sin(6 * d - 3 * n + f)
    Correction = Correction + 0.08096 * Sin(6 * d - 2 * n - f)
    Correction = Correction + 0.05963 * Sin(6 * d - 2 * n + f)
    Correction = Correction + 0.09403 * Sin(6 * d - n - f)
    Correction = Correction + 0.04217 * Sin(6 * d - n + f)
    Correction = Correction + 0.03674 * Sin(6 * d - f)
    Correction = Correction + 0.01465 * Sin(6 * d + f)
    Correction = Correction + 8.045 * Sin(dzeta_lune + 180 / Ct1)
    Correction = Correction + 0.416 * Sin(dzeta_lune + petit_l + 180 / Ct1)
    Correction = Correction + 0.456 * Sin(dzeta_lune - petit_l)
    Correction = Correction + 0.326 * Sin(dzeta_lune - 2 * f)
    Correction = Correction + 0.63 * Sin(18 * venus - 16 * longitude_moyenne_terre - petit_l + f + 26.54 / Ct1)
    Correction = Correction + 0.63 * Sin(18 * venus - 16 * longitude_moyenne_terre - petit_l - f + 26.54 / Ct1)
    Correction = Correction + 0.14 * Sin(longitude_moyenne_terre + d + 291.98 / Ct1)
    Correction = Correction + 0.07 * Sin(18 * venus - 16 * longitude_moyenne_terre - 2 * petit_l - f + 26.54 / Ct1)
    Correction = Correction + 0.067 * Sin(18 * venus - 16 * longitude_moyenne_terre + f + 26.54 / Ct1)
    Correction = Correction + 0.067 * Sin(5 * venus - 6 * longitude_moyenne_terre + 2 * d - f + 272.3 / Ct1)
    Correction = Correction + 1.375 * Sin(longitude_moyenne_terre + d + 275.13 / Ct1)
    Correction = Correction + 0.078 * Sin(longitude_moyenne_terre + d - petit_l + 95.13 / Ct1)
    Correction = Correction - 0.00001754 * 3600 / Ct1 * Sin(183.3 / Ct1 + 483202 / Ct1 * T2000)

    latitude = Correction / 3600 / Ct1
    b = latitude : latitude_lune = b
End_Sub
rem ============================================================================
' Cette SUB est pour le calcul de la position gocentrique de la Lune Position_Lune()
' Calcul de la distance qui separe la Terre de la Lune
SUB Distance_Terre_Lune()
    p = 385000.56 - 3.14837 * Cos(2 * f) + 79.66183 * Cos(n - 2 * f)
    p = p - 20905.32206 * Cos(n) - 0.10326 * Cos(n + 2 * f)
    p = p - 4.42124 * Cos(2 * n - 2 * f) - 569.92332 * Cos(2 * n)
    p = p - 23.21032 * Cos(3 * n) - 1.11693 * Cos(4 * n)
    p = p - 0.42242 * Cos(m - 3 * n) - 7.00293 * Cos(m - 2 * n)
    p = p - 129.62476 * Cos(m - n) + 0.33465 * Cos(m - n + 2 * f)
    p = p - 0.18568 * Cos(m - 2 * f) + 48.89 * Cos(m)
    p = p - 0.15803 * Cos(m + 2 * f) - 0.2481 * Cos(m + n - 2 * f)
    p = p + 104.75896 * Cos(m + n) + 5.75105 * Cos(m + 2 * n)
    p = p + 0.35509 * Cos(m + 3 * n) - 0.13618 * Cos(2 * m - 2 * n)
    p = p - 2.11728 * Cos(2 * m - n) + 1.06575 * Cos(2 * m)
    p = p + 1.16562 * Cos(2 * m + n) + 0.1141 * Cos(d - m - n)
    p = p + 0.49757 * Cos(d - m) + 0.10998 * Cos(d - m + n)
    p = p - 1.73852 * Cos(d - 2 * n) - 8.37909 * Cos(d - n)
    p = p - 0.79564 * Cos(d - 2 * f) + 108.74265 * Cos(d)
    p = p + 6.32199 * Cos(d + n) + 0.37852 * Cos(d + 2 * n)
    p = p + 0.33226 * Cos(d + m - 2 * n) + 0.85127 * Cos(d + m - n)
    p = p - 16.67533 * Cos(d + m) - 0.93335 * Cos(d + m + n)
    p = p - 0.14808 * Cos(2 * d - 3 * m - n) - 0.41076 * Cos(2 * d - 3 * m)
    p = p + 0.34304 * Cos(2 * d - 2 * m - 2 * n) - 4.95049 * Cos(2 * d - 2 * m - n)
    p = p - 9.88519 * Cos(2 * d - 2 * m) - 0.65758 * Cos(2 * d - 2 * m + n)
    p = p + 0.49506 * Cos(2 * d - m - 3 * n) + 10.05654 * Cos(2 * d - m - 2 * n)
    p = p + 0.32336 * Cos(2 * d - m - n - 2 * f) - 152.14314 * Cos(2 * d - m - n)
    p = p + 0.657 * Cos(2 * d - m - 2 * f) - 204.59357 * Cos(2 * d - m)
    p = p + 0.20942 * Cos(2 * d - m + n - 2 * f) - 12.83185 * Cos(2 * d - m + n)
    p = p - 0.84883 * Cos(2 * d - m + 2 * n) + 0.77854 * Cos(2 * d - 4 * n)
    p = p + 14.40262 * Cos(2 * d - 3 * n) + 0.47263 * Cos(2 * d - 2 * n - 2 * f)
    p = p + 246.15768 * Cos(2 * d - 2 * n) + 0.77405 * Cos(2 * d - 2 * n + 2 * f)
    p = p + 8.7517 * Cos(2 * d - n - 2 * f) - 3699.10468 * Cos(2 * d - n)
    p = p + 0.59633 * Cos(2 * d - n + 2 * f) + 10.32129 * Cos(2 * d - 2 * f)
    p = p - 2955.9665 * Cos(2 * d) + 4.13118 * Cos(2 * d + n - 2 * f)
    p = p - 170.73274 * Cos(2 * d + n) + 0.28399 * Cos(2 * d + 2 * n - 2 * f)
    p = p - 10.44472 * Cos(2 * d + 2 * n) - 0.66968 * Cos(2 * d + 3 * n)
    p = p + 0.16858 * Cos(2 * d + m - 3 * n) + 0.14368 * Cos(2 * d + m - 2 * n)
    p = p + 24.20935 * Cos(2 * d + m - n) - 0.13572 * Cos(2 * d + m - 2 * f)
    p = p + 30.82498 * Cos(2 * d + m) + 2.6165 * Cos(2 * d + m + n)
    p = p + 0.21252 * Cos(2 * d + m + 2 * n) - 0.10888 * Cos(2 * d + 2 * m - 2 * n)
    p = p + 2.3538 * Cos(2 * d + 2 * m - n) + 0.14764 * Cos(2 * d + 2 * m)
    p = p + 0.2556 * Cos(3 * d - m - n) - 0.15708 * Cos(3 * d - m)
    p = p + 0.86243 * Cos(3 * d - 2 * n) + 3.25823 * Cos(3 * d - n)
    p = p + 0.20099 * Cos(3 * d - 2 * f) - 1.41893 * Cos(3 * d)
    p = p - 0.21259 * Cos(3 * d + m - n) - 0.10766 * Cos(3 * d + m)
    p = p - 0.10834 * Cos(4 * d - 2 * m - 2 * n) - 0.27906 * Cos(4 * d - 2 * m - n)
    p = p - 0.12806 * Cos(4 * d - 2 * m) - 1.897 * Cos(4 * d - m - 2 * n)
    p = p - 3.95812 * Cos(4 * d - m - n) - 1.57145 * Cos(4 * d - m)
    p = p - 0.20286 * Cos(4 * d - m + n) - 0.51423 * Cos(4 * d - 3 * n)
    p = p - 21.63627 * Cos(4 * d - 2 * n) - 0.32176 * Cos(4 * d - n - 2 * f)
    p = p - 34.78245 * Cos(4 * d - n) - 0.50793 * Cos(4 * d - 2 * f)
    p = p - 11.64993 * Cos(4 * d) - 1.42255 * Cos(4 * d + n)
    p = p - 0.13922 * Cos(4 * d + 2 * n) + 0.23696 * Cos(4 * d + m - 2 * n)
    p = p + 0.5788 * Cos(4 * d + m - n) + 0.24453 * Cos(4 * d + m)
    p = p - 0.18316 * Cos(6 * d - 3 * n) - 0.4225 * Cos(6 * d - 2 * n)
    p = p - 0.28663 * Cos(6 * d - n)
END_SUB
rem ============================================================================


