
rem ============================================================================
rem                  Inclinaison dune figure
rem ============================================================================
rem Pour incliner une figure, il suffit dappliquer la matrice de rotation 
rem tous les points de la figure.
rem ============================================================================
rem
rem    __________________________________________________
rem   |                                                  |
rem   | xp = cx + (x1*cos(IncliDeg) - y1*sin(Inclideg))  |
rem   | yp = cy - (x1*sin(IncliDeg) + y1*cos(IncliDeg))  |
rem   |__________________________________________________|
rem
rem   xp,yp    : coordonnes du point  tracer
rem   cx,cy    : coordonnes du centre de la figure
rem   x1,y1    : coordonnes du point avant rotation
rem   IncliDeg : valeur de langle de rotation (en degr) , sens trigonomtrique
rem ============================================================================
rem Application :
rem Tracer une ellipse incline    
rem Appel : Ellipse_Inclinee(cx,cy,rx,ry,IncliDeg)

    2d_pen_color 255,0,0 : Ellipse_Inclinee(300,220,200,100,30)
    2d_pen_color 0,0,255 : Ellipse_Inclinee(300,220,200,100,150)

end
rem ============================================================================

' cx,cy : coordonnes du centre de rotation de l'ellipse
' Rx et Ry sont les longueurs des demi-diagonales
' IncliDeg : inclinaison en degrs de l'ellipse dans le sens trigonomtrique

SUB Ellipse_Inclinee(cx,cy,rx,ry,IncliDeg)
    dim_local a,x1,y1,xp,yp
    degrees
    IncliDeg = 0-IncliDeg
    ' Calcul du point Origine
    x1 = rx*sin(IncliDeg) : y1 = ry*cos(IncliDeg)
    xp = cx + (x1*cos(IncliDeg) - y1*sin(IncliDeg))
    yp = cy + (x1*sin(IncliDeg) + y1*cos(IncliDeg))
    2d_poly_from xp,yp

    for a = 0 to 360
        x1 = rx*sin(a + IncliDeg) : y1 = ry*cos(a + IncliDeg)
        ' Application de la matrice de rotation par rapport au centre cx,cy
        xp = cx + (x1*cos(IncliDeg) - y1*sin(IncliDeg))
        yp = cy + (x1*sin(IncliDeg) + y1*cos(IncliDeg))
        2d_poly_to xp,yp
    next a
END_SUB
rem ============================================================================