
rem ============================================================================
rem           Chuck Norris Programming Language (CNPL)
rem REF : https://www.xarg.org/puzzle/codingame/chuck-norris/
rem ============================================================================
rem Dans ce langage, le "0" est cod "00" et le "1" est cod "0".
rem Puis un espace, puis ensuite autant de "0" que le texte contient de "0"
rem ou "1" successifs.
rem ============================================================================
rem A lorigine cest un concept invent par Chuck Norris pour envoyer des
rem messages dits unaires.
rem On se propose ici, dcrire un programme qui,  partir dun texte en entre,
rem affiche le texte cod faon Chuck Norris en sortie.
rem ============================================================================
rem Principe dencodage :
rem   * Le texte en entre est constitu de caractres ASCII (7 bits)
rem   * Le texte encod en sortie est constitu de blocs de 0
rem   * Un bloc est spar dun autre bloc par un espace
rem   * Deux blocs conscutifs servent  produire une srie de bits de mme
rem     valeur ( 1  ou  0 uniquement ) :
rem     ** Premier bloc : il vaut toujours 0 ou 00.
rem        Sil vaut 0, alors la srie contients des 1, sinon elle contient des 0
rem     ** Deuxime bloc : le nombre de 0 dans ce bloc correspond au nombre de
rem        bits dans la srie
rem ============================================================================
rem Premier exemple
rem Prenons un exemple simple avec un texte constitu dun seul caractre :
rem C majuscule.
rem C en binaire vaut 1000011 ce qui donne avec la technique de Chuck Norris :
rem   0 0     (la premire srie  est compose dun seul 1)
rem   00 0000 (la deuxime srie  est compose de quatre 0)
rem   0 00    (la troisime srie est compose de deux   1)
rem
rem C vaut donc : 0 0 00 0000 0 00
rem ============================================================================
rem Deuxime exemple :
rem Nous voulons encoder le texte CC (soit les 14 bits 10000111000011) :
rem   0 0     (un seul 1)
rem   00 0000 (quatre 0)
rem   0 000   (trois 1)
rem   00 0000 (quatre 0)
rem   0 00    (deux 1)
rem
rem CC vaut donc : 0 0 00 0000 0 000 00 0000 0 00
rem ============================================================================
dim phrase$
width 0,1400

' phrase$ = "C"        : ' <---  0 0 00 0000 0 00
' phrase$ = "CC"       : ' <---  0 0 00 0000 0 000 00 0000 0 00
' phrase$ = "%"        : ' <---  00 0 0 0 00 00 0 0 00 0 0 0
' phrase$ = "Hello"    : ' <---  0 0 00 00 0 0 00 000 0 00 00 00 0 0 00 0 0 000 00
                       '       0 0 00 00 00 0 00 00 0 0 00 00 00 0 00 00 0 0 0000
phrase$ = "Vive Panoramic"
print "Codage unaire du texte : " + phrase$
print Binaire2Unaire$(Texte2Binaire$(phrase$))

end
rem ============================================================================
FNC Texte2Binaire$(texte$)
    dim_local decimal,binaire$,i
    for i = 1 to len(texte$)
        decimal = asc(mid$(texte$,i,1))
        binaire$ = binaire$ + Decimal2Binaire$(decimal)        
    next i
    result binaire$
END_FNC
rem ============================================================================
FNC Binaire2Unaire$(binaire$)
    dim_local unaire$,caractere$,i,j,k,bloc$
    unaire$ = ""
    i = 0
    while i < len(binaire$)
        bloc$ = ""
        caractere$ = mid$(binaire$,i+1,1)
        j = 1
        while ((i+j) < len(binaire$)) and (mid$(binaire$,i+j+1,1) = caractere$)
            j = j + 1
        end_while
        if caractere$ = "0"
           unaire$ = unaire$ + "00 "
        else
           unaire$ = unaire$ + "0 "
        end_if
        i = i + j
        for k = 1 to j : bloc$ = bloc$ + "0" : next k
        unaire$ = unaire$ + bloc$ + " "
        
    end_while
    unaire$ = rtrim$(unaire$)
    result unaire$
END_FNC
rem ============================================================================
' Convertir un nombre dcimal en un nombre en binaire (7 bits)
' Paramtre : un nombre en dcimal
' Le rsultat est une chane de caractres reprsentant un nombre en binaire
' sur 7 bits
FNC Decimal2Binaire$(dec)
    dim_local n,tmp$,ret$
    n = dec
    while n > 1
        tmp$ = str$(n-2*int(n/2)) + tmp$
        n = int(n/2)
    end_while
    ret$ = str$(n) + tmp$
    while len(ret$) < 7
        ret$ = "0" + ret$
    end_while
    result ret$    
END_FNC
rem ============================================================================