
rem ============================================================================
rem             Les mathmatiques pour
rem           les transformations du plan
rem ============================================================================
rem Les principales transformations du plan sont :
rem * les translations,
rem * les changements dchelles,
rem * les symtries,
rem * les rotations,
rem * les cisaillements.
rem ============================================================================
rem Le calcul matriciel rsout tous ces problmes.
rem Soient (x,y) les coordonnes dun point du plan cartsien.
rem On peut considrer ces coordonnes comme une matrice de 1 ligne sur 2 colonnes
rem que nous noterons matrice (1 X 2) (lire matrice 1 croix 2).
rem ============================================================================
rem La matrice gnrale :
rem  
rem   A B
rem   C D
rem
rem est une matrice de 2 lignes sur 2 colonnes et sera note matrice (2 X 2)
rem (lire matrice 2 croix 2)
rem ============================================================================
rem Le produit matriciel de la matrice (1 X 2) et de la matrice (2 X 2) donne comme
rem rsultat (A*x+C*y  B*x+D*y)
rem
rem Donc, tout point du plan (x,y) multipli par la matrice (2 X 2) a pour transform
rem un nouveau point du plan (xp,yp) tel que :
rem    ____________________
rem   |                    |
rem   |   xp = A*x + C*y   |
rem   |   yp = B*x + D*y   |
rem   |____________________|
rem
rem La transformation obtenue dpendra des valeurs donnes aux variables A,B,C,D.
rem ============================================================================
rem Pour information:
rem *****************
rem Voici les diffrentes matrices de transformations:
rem ----------------------------------------------------------------------------
rem Les changements dchelles sont contrls par la matrice :
rem
rem  A  0
rem  0  D
rem
rem En effet le produit matriciel donne A*x  D*y do xp = A*x ; yp = D*y
rem ----------------------------------------------------------------------------
rem Les symtries : les matrices qui contrlent les symtries ne sont que des cas
rem particuliers de la matrice changement dchelles dans laquelle A et/ou D sont
rem ngatifs.
rem
rem La matrice:
rem
rem  -1  0
rem   0  1
rem
rem produira une symtrie par rapport  laxe des Y
rem En effet le produit matriciel donne xp = -x ; yp = y
rem
rem La matrice:
rem
rem  1  0
rem  0 -1
rem
rem produira une symtrie par rapport  laxe des X
rem En effet, le produit matriciel donne xp = x ; yp = -y
rem
rem La matrice:
rem
rem  -1  0
rem   0 -1
rem
rem produira une symtrie par rapport aux deux axes c..d une symtrie
rem centrale par rapport  lorigine.
rem En effet, le produit matriciel donne xp = -x ; yp = -y
rem ----------------------------------------------------------------------------
rem Les cisaillements : les matrices qui contrlent les cisaillements sont
rem
rem   1  0
rem   C  1
rem
rem donnera un cisaillement en x
rem
rem   1  B
rem   0  1
rem
rem donnera un cisaillement en y
rem
rem   1  B
rem   C  1
rem
rem donnera un cisaillement dans les deux directions
rem ----------------------------------------------------------------------------
rem Les rotations : Les matrices qui contrlent les rotations sont :
rem
rem   cos(theta)  sin(theta)
rem  -sin(theta)  cos(theta)
rem
rem Les coefficients A,B,C,D de la matrice gnrale sont dans ce cas :
rem A = cos(theta) ; B = sin(theta) ; C = -sin(theta) ; D = cos(theta)
rem Avec theta langle de rotation du point autour de lorigine des axes.
rem Cet angle est exprim en RADIANS.
rem ============================================================================
rem &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
rem ============================================================================
rem
rem Application : rotation dun polygone

dim n : n = 4  : ' Nombre des sommets du polygone, ici c'est un carr
dim x(n+1),y(n+1)
dim A,B,C,D    : ' termes de la matrice rotation
dim xc,yc      : ' coordonnes du centre de l'cran
dim theta      : ' angle de rotation
dim p          : ' pas de variation de l'angle de rotation

caption 0 ,"Rotation d'un polygone autour de l'origine des axes"
picture 10 : full_space 10 : 2d_target_is 10
 
p = pi/18 :  '  essayez avec p = pi/72 ou p = pi/36  ou p = pi/9 ou p = pi/144
xc = width_client(10)/2  : ' coordonnes du centre de l'cran et ...
yc = height_client(10)/2 : ' ... aussi centre de rotation

Init_polygone() : ' Mmorisation des somments du polygone
Trace_axes()    : ' Trac des axes

' Faire tourner le polygone autour du centre de rotation par un pas de p radians
for theta = 0 to 2*pi step p
    Rotation(theta) : ' Faire tourner le polygone
    pause 200       : ' pour suivre la rotation, valeur  modifier ou supprimer
next theta
end
rem ============================================================================
rem &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
rem ============================================================================
' Coordonnes relatives par rapport au centre de l'cran des sommets du polygone
' (ici un carr de 150 pixels de ct)

DATA 0,0     : ' 1er point
DATA 150,0   : ' 2me point
DATA 150,150 : ' 3me point
DATA 0,150   : ' 4me point

rem ============================================================================
' Retourne les coefficients de la matrice(2 X 2) de rotation autour de l'origine
SUB Matrice_Rotation(theta)
    A = cos(theta) : B = sin(theta) : C = 0-sin(theta) : D = cos(theta)
END_SUB
rem ============================================================================
' Mmorisation des somments du polygone
SUB Init_Polygone()
    dim_local i
    for i = 1 to n :read x(i):read y(i): next i
    x(n+1) = x(1) : y(n+1) = y(1) : ' Pour fermer le polygone
END_SUB
rem ============================================================================
' Tracer des axes
SUB Trace_Axes()
    2d_line 0,yc,2*xc,yc : ' tracer l'axe des X
    2d_line xc,0,xc,2*yc : ' tracer l'axe des Y
END_SUB
rem ============================================================================
' Effectuer une rotation du polygone d'un angle theta en RADIANS
' puis tracer le nouveau polygone
SUB Rotation(theta)
    Dim_local xp,yp,i
    Matrice_Rotation(theta)  : ' Calcul des coefficients de la matrice de rotation  
    xp = A * x(1) + C * y(1) : ' Calcul des nouvelles coordonnes du 1er point ...
    yp = B * x(1) + D * y(1) : ' ... aprs avoir subi la rotation
    2d_poly_from xc+xp,yc+yp : ' Trac du point de dpart du polygone
    for i = 2 to n + 1
        xp = A * x(i) + C * y(i) : ' Calcul des nouvelles coordonnes du point ...
        yp = B * x(i) + D * y(i) : ' ... suivant aprs avoir subi la rotation
        2d_poly_to xc+xp,yc-yp   : ' Relier au point suivant
    next i
END_SUB
rem ============================================================================
rem &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
rem ============================================================================